@@ -1,6 +1,6 @@
 {- git-annex monad
  -
- - Copyright 2010-2020 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2021 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU AGPL version 3 or higher.
  -}
@@ -22,7 +22,7 @@ module Annex (
 	setOutput,
 	getFlag,
 	getField,
-	addCleanup,
+	addCleanupAction,
 	gitRepo,
 	inRepo,
 	fromRepo,
@@ -32,6 +32,7 @@ module Annex (
 	changeGitRepo,
 	adjustGitRepo,
 	addGitConfigOverride,
+	getGitConfigOverrides,
 	getRemoteGitConfig,
 	withCurrentState,
 	changeDirectory,
@@ -70,10 +71,14 @@ import Types.WorkerPool
 import Types.IndexFiles
 import Types.CatFileHandles
 import Types.RemoteConfig
+import Types.TransferrerPool
+import Types.VectorClock
+import Annex.VectorClock.Utility
 import qualified Database.Keys.Handle as Keys
 import Utility.InodeCache
 import Utility.Url
 import Utility.ResourcePool
+import Utility.HumanTime
 
 import "mtl" Control.Monad.Reader
 import Control.Concurrent
@@ -81,6 +86,7 @@ import Control.Concurrent.STM
 import qualified Control.Monad.Fail as Fail
 import qualified Data.Map.Strict as M
 import qualified Data.Set as S
+import Data.Time.Clock.POSIX
 
 {- git-annex's monad is a ReaderT around an AnnexState stored in a MVar.
  - The MVar is not exposed outside this module.
@@ -109,6 +115,7 @@ data AnnexState = AnnexState
 	, repoadjustment :: (Git.Repo -> IO Git.Repo)
 	, gitconfig :: GitConfig
 	, gitconfigadjustment :: (GitConfig -> GitConfig)
+	, gitconfigoverride :: [String]
 	, gitremotes :: Maybe [Git.Repo]
 	, backend :: Maybe (BackendA Annex)
 	, remotes :: [Types.Remote.RemoteA Annex]
@@ -118,6 +125,7 @@ data AnnexState = AnnexState
 	, fast :: Bool
 	, daemon :: Bool
 	, branchstate :: BranchState
+	, getvectorclock :: IO VectorClock
 	, repoqueue :: Maybe (Git.Queue.Queue Annex)
 	, catfilehandles :: CatFileHandles
 	, hashobjecthandle :: Maybe HashObjectHandle
@@ -125,8 +133,11 @@ data AnnexState = AnnexState
 	, checkignorehandle :: Maybe (ResourcePool CheckIgnoreHandle)
 	, forcebackend :: Maybe String
 	, globalnumcopies :: Maybe NumCopies
+	, globalmincopies :: Maybe MinCopies
 	, forcenumcopies :: Maybe NumCopies
+	, forcemincopies :: Maybe MinCopies
 	, limit :: ExpandableMatcher Annex
+	, timelimit :: Maybe (Duration, POSIXTime)
 	, uuiddescmap :: Maybe UUIDDescMap
 	, preferredcontentmap :: Maybe (FileMatcherMap Annex)
 	, requiredcontentmap :: Maybe (FileMatcherMap Annex)
@@ -139,7 +150,8 @@ data AnnexState = AnnexState
 	, sshstalecleaned :: TMVar Bool
 	, flags :: M.Map String Bool
 	, fields :: M.Map String String
-	, cleanup :: M.Map CleanupAction (Annex ())
+	, cleanupactions :: M.Map CleanupAction (Annex ())
+	, signalactions :: TVar (M.Map SignalAction (Int -> IO ()))
 	, sentinalstatus :: Maybe SentinalStatus
 	, useragent :: Maybe String
 	, errcounter :: Integer
@@ -156,20 +168,25 @@ data AnnexState = AnnexState
 	, cachedgitenv :: Maybe (AltIndexFile, FilePath, [(String, String)])
 	, urloptions :: Maybe UrlOptions
 	, insmudgecleanfilter :: Bool
+	, transferrerpool :: TransferrerPool
 	}
 
 newState :: GitConfig -> Git.Repo -> IO AnnexState
 newState c r = do
 	emptyactiveremotes <- newMVar M.empty
 	emptyactivekeys <- newTVarIO M.empty
+	si <- newTVarIO M.empty
 	o <- newMessageState
 	sc <- newTMVarIO False
 	kh <- Keys.newDbHandle
+	tp <- newTransferrerPool
+	vc <- startVectorClock
 	return $ AnnexState
 		{ repo = r
 		, repoadjustment = return
 		, gitconfig = c
 		, gitconfigadjustment = id
+		, gitconfigoverride = []
 		, gitremotes = Nothing
 		, backend = Nothing
 		, remotes = []
@@ -179,6 +196,7 @@ newState c r = do
 		, fast = False
 		, daemon = False
 		, branchstate = startBranchState
+		, getvectorclock = vc
 		, repoqueue = Nothing
 		, catfilehandles = catFileHandlesNonConcurrent
 		, hashobjecthandle = Nothing
@@ -186,8 +204,11 @@ newState c r = do
 		, checkignorehandle = Nothing
 		, forcebackend = Nothing
 		, globalnumcopies = Nothing
+		, globalmincopies = Nothing
 		, forcenumcopies = Nothing
+		, forcemincopies = Nothing
 		, limit = BuildingMatcher []
+		, timelimit = Nothing
 		, uuiddescmap = Nothing
 		, preferredcontentmap = Nothing
 		, requiredcontentmap = Nothing
@@ -200,7 +221,8 @@ newState c r = do
 		, sshstalecleaned = sc
 		, flags = M.empty
 		, fields = M.empty
-		, cleanup = M.empty
+		, cleanupactions = M.empty
+		, signalactions = si
 		, sentinalstatus = Nothing
 		, useragent = Nothing
 		, errcounter = 0
@@ -217,6 +239,7 @@ newState c r = do
 		, cachedgitenv = Nothing
 		, urloptions = Nothing
 		, insmudgecleanfilter = False
+		, transferrerpool = tp
 		}
 
 {- Makes an Annex state object for the specified git repo.
@@ -224,7 +247,7 @@ newState c r = do
  - any necessary git repo fixups. -}
 new :: Git.Repo -> IO AnnexState
 new r = do
-	r' <- Git.Config.read =<< Git.relPath r
+	r' <- Git.Config.read r
 	let c = extractGitConfig FromGitConfig r'
 	newState c =<< fixupRepo r' c
 
@@ -285,9 +308,9 @@ setField field value = changeState $ \s ->
 	s { fields = M.insert field value $ fields s }
 
 {- Adds a cleanup action to perform. -}
-addCleanup :: CleanupAction -> Annex () -> Annex ()
-addCleanup k a = changeState $ \s ->
-	s { cleanup = M.insert k a $ cleanup s }
+addCleanupAction :: CleanupAction -> Annex () -> Annex ()
+addCleanupAction k a = changeState $ \s ->
+	s { cleanupactions = M.insert k a $ cleanupactions s }
 
 {- Sets the type of output to emit. -}
 setOutput :: OutputType -> Annex ()
@@ -345,12 +368,14 @@ adjustGitRepo a = do
 	changeGitRepo =<< gitRepo
 
 {- Adds git config setting, like "foo=bar". It will be passed with -c
- - to git processes. The config setting is also recorded in the repo,
+ - to git processes. The config setting is also recorded in the Repo,
  - and the GitConfig is updated. -}
 addGitConfigOverride :: String -> Annex ()
-addGitConfigOverride v = adjustGitRepo $ \r ->
-	Git.Config.store (encodeBS' v) Git.Config.ConfigList $
-		r { Git.gitGlobalOpts = go (Git.gitGlobalOpts r) }
+addGitConfigOverride v = do
+	adjustGitRepo $ \r ->
+		Git.Config.store (encodeBS' v) Git.Config.ConfigList $
+			r { Git.gitGlobalOpts = go (Git.gitGlobalOpts r) }
+	changeState $ \s -> s { gitconfigoverride = v : gitconfigoverride s }
   where
 	-- Remove any prior occurrance of the setting to avoid
 	-- building up many of them when the adjustment is run repeatedly,
@@ -359,6 +384,10 @@ addGitConfigOverride v = adjustGitRepo $ \r ->
 	go (Param "-c": Param v':rest) | v' == v = go rest
 	go (c:rest) = c : go rest
 
+{- Values that were passed to addGitConfigOverride. -}
+getGitConfigOverrides :: Annex [String]
+getGitConfigOverrides = reverse <$> getState gitconfigoverride
+
 {- Changing the git Repo data also involves re-extracting its GitConfig. -}
 changeGitRepo :: Git.Repo -> Annex ()
 changeGitRepo r = do
