@@ -41,6 +41,7 @@ import Data.Function
 import Data.Char
 import Data.ByteString.Builder
 import Control.Concurrent (threadDelay)
+import qualified System.FilePath.ByteString as P
 
 import Annex.Common
 import Types.BranchState
@@ -76,6 +77,7 @@ import Annex.Branch.Transitions
 import qualified Annex
 import Annex.Hook
 import Utility.Directory.Stream
+import qualified Utility.RawFilePath as R
 
 {- Name of the branch that is used to store git-annex's information. -}
 name :: Git.Ref
@@ -393,24 +395,26 @@ commitIndex' jl branchref message basemessage retrynum parents = do
 
 {- Lists all files on the branch. including ones in the journal
  - that have not been committed yet. There may be duplicates in the list. -}
-files :: Annex [RawFilePath]
+files :: Annex ([RawFilePath], IO Bool)
 files = do
 	_  <- update
+	(bfs, cleanup) <- branchFiles
 	-- ++ forces the content of the first list to be buffered in memory,
 	-- so use getJournalledFilesStale which should be much smaller most
 	-- of the time. branchFiles will stream as the list is consumed.
-	(++)
+	l <- (++)
 		<$> (map toRawFilePath <$> getJournalledFilesStale)
-		<*> branchFiles
+		<*> pure bfs
+	return (l, cleanup)
 
 {- Files in the branch, not including any from journalled changes,
  - and without updating the branch. -}
-branchFiles :: Annex [RawFilePath]
+branchFiles :: Annex ([RawFilePath], IO Bool)
 branchFiles = withIndex $ inRepo branchFiles'
 
-branchFiles' :: Git.Repo -> IO [RawFilePath]
-branchFiles' = Git.Command.pipeNullSplitZombie'
-	(lsTreeParams Git.LsTree.LsTreeRecursive fullname [Param "--name-only"])
+branchFiles' :: Git.Repo -> IO ([RawFilePath], IO Bool)
+branchFiles' = Git.Command.pipeNullSplit' $
+	lsTreeParams Git.LsTree.LsTreeRecursive fullname [Param "--name-only"]
 
 {- Populates the branch's index file with the current branch contents.
  - 
@@ -444,7 +448,7 @@ mergeIndex jl branches = do
 prepareModifyIndex :: JournalLocked -> Annex ()
 prepareModifyIndex _jl = do
 	index <- fromRepo gitAnnexIndex
-	void $ liftIO $ tryIO $ removeFile $ index ++ ".lock"
+	void $ liftIO $ tryIO $ R.removeLink (index <> ".lock")
 
 {- Runs an action using the branch's index file. -}
 withIndex :: Annex a -> Annex a
@@ -453,7 +457,7 @@ withIndex' :: Bool -> Annex a -> Annex a
 withIndex' bootstrapping a = withIndexFile AnnexIndexFile $ \f -> do
 	checkIndexOnce $ unlessM (liftIO $ doesFileExist f) $ do
 		unless bootstrapping create
-		createAnnexDirectory $ takeDirectory f
+		createAnnexDirectory $ toRawFilePath $ takeDirectory f
 		unless bootstrapping $ inRepo genIndex
 	a
 
@@ -475,7 +479,7 @@ forceUpdateIndex jl branchref = do
 {- Checks if the index needs to be updated. -}
 needUpdateIndex :: Git.Ref -> Annex Bool
 needUpdateIndex branchref = do
-	f <- fromRepo gitAnnexIndexStatus
+	f <- fromRawFilePath <$> fromRepo gitAnnexIndexStatus
 	committedref <- Git.Ref . firstLine' <$>
 		liftIO (catchDefaultIO mempty $ B.readFile f)
 	return (committedref /= branchref)
@@ -504,19 +508,19 @@ stageJournal jl commitindex = withIndex $ withOtherTmp $ \tmpdir -> do
 	prepareModifyIndex jl
 	g <- gitRepo
 	let dir = gitAnnexJournalDir g
-	(jlogf, jlogh) <- openjlog tmpdir
+	(jlogf, jlogh) <- openjlog (fromRawFilePath tmpdir)
 	h <- hashObjectHandle
 	withJournalHandle $ \jh ->
 		Git.UpdateIndex.streamUpdateIndex g
 			[genstream dir h jh jlogh]
 	commitindex
-	liftIO $ cleanup dir jlogh jlogf
+	liftIO $ cleanup (fromRawFilePath dir) jlogh jlogf
   where
 	genstream dir h jh jlogh streamer = readDirectory jh >>= \case
 		Nothing -> return ()
 		Just file -> do
 			unless (dirCruft file) $ do
-				let path = dir </> file
+				let path = dir P.</> toRawFilePath file
 				sha <- Git.HashObject.hashFile h path
 				hPutStrLn jlogh file
 				streamer $ Git.UpdateIndex.updateIndexLine
@@ -531,7 +535,7 @@ stageJournal jl commitindex = withIndex $ withOtherTmp $ \tmpdir -> do
 		stagedfs <- lines <$> hGetContents jlogh
 		mapM_ (removeFile . (dir </>)) stagedfs
 		hClose jlogh
-		nukeFile jlogf
+		removeWhenExistsWith (R.removeLink) (toRawFilePath jlogf)
 	openjlog tmpdir = liftIO $ openTempFile tmpdir "jlog"
 
 {- This is run after the refs have been merged into the index,
@@ -620,10 +624,11 @@ performTransitionsLocked jl ts neednewlocalbranch transitionedrefs = do
 		remoteconfigmap <- calcRemoteConfigMap <$> getStaged remoteLog
 		-- partially apply, improves performance
 		let changers' = map (\c -> c config trustmap remoteconfigmap) changers
-		fs <- branchFiles
+		(fs, cleanup) <- branchFiles
 		forM_ fs $ \f -> do
 			content <- getStaged f
 			apply changers' f content
+		liftIO $ void cleanup
 	apply [] _ _ = return ()
 	apply (changer:rest) file content = case changer file content of
 		PreserveFile -> apply rest file content
@@ -663,7 +668,7 @@ getIgnoredRefs =
 	S.fromList . mapMaybe Git.Sha.extractSha . B8.lines <$> content
   where
 	content = do
-		f <- fromRepo gitAnnexIgnoredRefs
+		f <- fromRawFilePath <$> fromRepo gitAnnexIgnoredRefs
 		liftIO $ catchDefaultIO mempty $ B.readFile f
 
 addMergedRefs :: [(Git.Sha, Git.Branch)] -> Annex ()
@@ -681,7 +686,7 @@ getMergedRefs = S.fromList . map fst <$> getMergedRefs'
 
 getMergedRefs' :: Annex [(Git.Sha, Git.Branch)]
 getMergedRefs' = do
-	f <- fromRepo gitAnnexMergedRefs
+	f <- fromRawFilePath <$> fromRepo gitAnnexMergedRefs
 	s <- liftIO $ catchDefaultIO mempty $ B.readFile f
 	return $ map parse $ B8.lines s
   where
