@@ -5,6 +5,8 @@
  - Licensed under the GNU AGPL version 3 or higher.
  -}
 
+{-# LANGUAGE OverloadedStrings #-}
+
 module Annex.ChangedRefs
 	( ChangedRefs(..)
 	, ChangedRefsHandle
@@ -17,6 +19,7 @@ module Annex.ChangedRefs
 import Annex.Common
 import Utility.DirWatcher
 import Utility.DirWatcher.Types
+import Utility.Directory.Create
 import qualified Git
 import Git.Sha
 import qualified Utility.SimpleProtocol as Proto
@@ -25,6 +28,7 @@ import Control.Concurrent
 import Control.Concurrent.STM
 import Control.Concurrent.STM.TBMChan
 import qualified Data.ByteString as S
+import qualified System.FilePath.ByteString as P
 
 newtype ChangedRefs = ChangedRefs [Git.Ref]
 	deriving (Show)
@@ -77,8 +81,8 @@ watchChangedRefs = do
 	chan <- liftIO $ newTBMChanIO 100
 	
 	g <- gitRepo
-	let gittop = fromRawFilePath (Git.localGitDir g)
-	let refdir = gittop </> "refs"
+	let gittop = Git.localGitDir g
+	let refdir = gittop P.</> "refs"
 	liftIO $ createDirectoryUnder gittop refdir
 
 	let notifyhook = Just $ notifyHook chan
@@ -89,7 +93,9 @@ watchChangedRefs = do
 
 	if canWatch
 		then do
-			h <- liftIO $ watchDir refdir (const False) True hooks id
+			h <- liftIO $ watchDir
+				(fromRawFilePath refdir)
+				(const False) True hooks id
 			return $ Just $ ChangedRefsHandle h chan
 		else return Nothing
 
