@@ -9,12 +9,6 @@
 
 module Annex.Content.PointerFile where
 
-#if ! defined(mingw32_HOST_OS)
-import System.Posix.Files
-#else
-import System.PosixCompat.Files
-#endif
-
 import Annex.Common
 import Annex.Perms
 import Annex.Link
@@ -22,8 +16,10 @@ import Annex.ReplaceFile
 import Annex.InodeSentinal
 import Annex.Content.LowLevel
 import Utility.InodeCache
+import qualified Utility.RawFilePath as R
 #if ! defined(mingw32_HOST_OS)
 import Utility.Touch
+import System.Posix.Files (modificationTimeHiRes)
 #endif
 
 {- Populates a pointer file with the content of a key. 
@@ -37,12 +33,12 @@ populatePointerFile restage k obj f = go =<< liftIO (isPointerFile f)
   where
 	go (Just k') | k == k' = do
 		let f' = fromRawFilePath f
-		destmode <- liftIO $ catchMaybeIO $ fileMode <$> getFileStatus f'
-		liftIO $ nukeFile f'
+		destmode <- liftIO $ catchMaybeIO $ fileMode <$> R.getFileStatus f
+		liftIO $ removeWhenExistsWith R.removeLink f
 		(ic, populated) <- replaceWorkTreeFile f' $ \tmp -> do
 			let tmp' = toRawFilePath tmp
-			ok <- linkOrCopy k (fromRawFilePath obj) tmp destmode >>= \case
-				Just _ -> thawContent tmp >> return True
+			ok <- linkOrCopy k obj tmp' destmode >>= \case
+				Just _ -> thawContent tmp' >> return True
 				Nothing -> liftIO (writePointerFile tmp' k destmode) >> return False
 			ic <- withTSDelta (liftIO . genInodeCache tmp')
 			return (ic, ok)
@@ -60,15 +56,16 @@ depopulatePointerFile key file = do
 	let file' = fromRawFilePath file
 	st <- liftIO $ catchMaybeIO $ getFileStatus file'
 	let mode = fmap fileMode st
-	secureErase file'
-	liftIO $ nukeFile file'
+	secureErase file
+	liftIO $ removeWhenExistsWith R.removeLink file
 	ic <- replaceWorkTreeFile file' $ \tmp -> do
-		liftIO $ writePointerFile (toRawFilePath tmp) key mode
+		let tmp' = toRawFilePath tmp
+		liftIO $ writePointerFile tmp' key mode
 #if ! defined(mingw32_HOST_OS)
 		-- Don't advance mtime; this avoids unncessary re-smudging
 		-- by git in some cases.
 		liftIO $ maybe noop
-			(\t -> touch tmp t False)
+			(\t -> touch tmp' t False)
 			(fmap modificationTimeHiRes st)
 #endif
 		withTSDelta (liftIO . genInodeCache (toRawFilePath tmp))
