@@ -93,8 +93,8 @@ fixupUnusualRepos r@(Repo { location = l@(Local { worktree = Just w, gitdir = d
 	| needsSubmoduleFixup r = do
 		when (coreSymlinks c) $
 			(replacedotgit >> unsetcoreworktree)
-				`catchNonAsync` \_e -> hPutStrLn stderr
-					"warning: unable to convert submodule to form that will work with git-annex"
+				`catchNonAsync` \e -> hPutStrLn stderr $
+					"warning: unable to convert submodule to form that will work with git-annex: " ++ show e
 		return $ r'
 			{ config = M.delete "core.worktree" (config r)
 			}
@@ -102,8 +102,8 @@ fixupUnusualRepos r@(Repo { location = l@(Local { worktree = Just w, gitdir = d
 		( do
 			when (coreSymlinks c) $
 				(replacedotgit >> worktreefixup)
-					`catchNonAsync` \_e -> hPutStrLn stderr
-						"warning: unable to convert .git file to symlink that will work with git-annex"
+					`catchNonAsync` \e -> hPutStrLn stderr $
+						"warning: unable to convert .git file to symlink that will work with git-annex: " ++ show e
 			return r'
 		, return r
 		)
@@ -115,9 +115,8 @@ fixupUnusualRepos r@(Repo { location = l@(Local { worktree = Just w, gitdir = d
 		removeWhenExistsWith R.removeLink dotgit
 		R.createSymbolicLink linktarget dotgit
 	
-	unsetcoreworktree =
-		maybe (error "unset core.worktree failed") (\_ -> return ())
-			=<< Git.Config.unset "core.worktree" r
+	-- Unsetting a config fails if it's not set, so ignore failure.
+	unsetcoreworktree = void $ Git.Config.unset "core.worktree" r
 	
 	worktreefixup =
 		-- git-worktree sets up a "commondir" file that contains
