@@ -26,10 +26,11 @@ import Annex.Perms
 import Annex.LockPool
 
 import qualified Data.Map as M
+import qualified System.FilePath.ByteString as P
 
 {- Create a specified lock file, and takes a shared lock, which is retained
  - in the cache. -}
-lockFileCached :: FilePath -> Annex ()
+lockFileCached :: RawFilePath -> Annex ()
 lockFileCached file = go =<< fromLockCache file
   where
 	go (Just _) = noop -- already locked
@@ -42,7 +43,7 @@ lockFileCached file = go =<< fromLockCache file
 #endif
 		changeLockCache $ M.insert file lockhandle
 
-unlockFile :: FilePath -> Annex ()
+unlockFile :: RawFilePath -> Annex ()
 unlockFile file = maybe noop go =<< fromLockCache file
   where
 	go lockhandle = do
@@ -52,7 +53,7 @@ unlockFile file = maybe noop go =<< fromLockCache file
 getLockCache :: Annex LockCache
 getLockCache = getState lockcache
 
-fromLockCache :: FilePath -> Annex (Maybe LockHandle)
+fromLockCache :: RawFilePath -> Annex (Maybe LockHandle)
 fromLockCache file = M.lookup file <$> getLockCache
 
 changeLockCache :: (LockCache -> LockCache) -> Annex ()
@@ -62,10 +63,10 @@ changeLockCache a = do
 
 {- Runs an action with a shared lock held. If an exclusive lock is held,
  - blocks until it becomes free. -}
-withSharedLock :: (Git.Repo -> FilePath) -> Annex a -> Annex a
+withSharedLock :: (Git.Repo -> RawFilePath) -> Annex a -> Annex a
 withSharedLock getlockfile a = debugLocks $ do
 	lockfile <- fromRepo getlockfile
-	createAnnexDirectory $ takeDirectory lockfile
+	createAnnexDirectory $ P.takeDirectory lockfile
 	mode <- annexFileMode
 	bracket (lock mode lockfile) (liftIO . dropLock) (const a)
   where
@@ -77,17 +78,17 @@ withSharedLock getlockfile a = debugLocks $ do
 
 {- Runs an action with an exclusive lock held. If the lock is already
  - held, blocks until it becomes free. -}
-withExclusiveLock :: (Git.Repo -> FilePath) -> Annex a -> Annex a
+withExclusiveLock :: (Git.Repo -> RawFilePath) -> Annex a -> Annex a
 withExclusiveLock getlockfile a = bracket
 	(takeExclusiveLock getlockfile)
 	(liftIO . dropLock)
 	(const a)
 
 {- Takes an exclusive lock, blocking until it's free. -}
-takeExclusiveLock :: (Git.Repo -> FilePath) -> Annex LockHandle
+takeExclusiveLock :: (Git.Repo -> RawFilePath) -> Annex LockHandle
 takeExclusiveLock getlockfile = debugLocks $ do
 	lockfile <- fromRepo getlockfile
-	createAnnexDirectory $ takeDirectory lockfile
+	createAnnexDirectory $ P.takeDirectory lockfile
 	mode <- annexFileMode
 	lock mode lockfile
   where
@@ -99,10 +100,10 @@ takeExclusiveLock getlockfile = debugLocks $ do
 
 {- Tries to take an exclusive lock and run an action. If the lock is
  - already held, returns Nothing. -}
-tryExclusiveLock :: (Git.Repo -> FilePath) -> Annex a -> Annex (Maybe a)
+tryExclusiveLock :: (Git.Repo -> RawFilePath) -> Annex a -> Annex (Maybe a)
 tryExclusiveLock getlockfile a = debugLocks $ do
 	lockfile <- fromRepo getlockfile
-	createAnnexDirectory $ takeDirectory lockfile
+	createAnnexDirectory $ P.takeDirectory lockfile
 	mode <- annexFileMode
 	bracket (lock mode lockfile) (liftIO . unlock) go
   where
