@@ -31,24 +31,26 @@ import Git
 import Git.ConfigTypes
 import qualified Annex
 import Config
+import Utility.Directory.Create
+import qualified Utility.RawFilePath as R
 
 withShared :: (SharedRepository -> Annex a) -> Annex a
 withShared a = a =<< coreSharedRepository <$> Annex.getGitConfig
 
-setAnnexFilePerm :: FilePath -> Annex ()
+setAnnexFilePerm :: RawFilePath -> Annex ()
 setAnnexFilePerm = setAnnexPerm False
 
-setAnnexDirPerm :: FilePath -> Annex ()
+setAnnexDirPerm :: RawFilePath -> Annex ()
 setAnnexDirPerm = setAnnexPerm True
 
 {- Sets appropriate file mode for a file or directory in the annex,
  - other than the content files and content directory. Normally,
  - don't change the mode, but with core.sharedRepository set,
  - allow the group to write, etc. -}
-setAnnexPerm :: Bool -> FilePath -> Annex ()
+setAnnexPerm :: Bool -> RawFilePath -> Annex ()
 setAnnexPerm = setAnnexPerm' Nothing
 
-setAnnexPerm' :: Maybe ([FileMode] -> FileMode -> FileMode) -> Bool -> FilePath -> Annex ()
+setAnnexPerm' :: Maybe ([FileMode] -> FileMode -> FileMode) -> Bool -> RawFilePath -> Annex ()
 setAnnexPerm' modef isdir file = unlessM crippledFileSystem $
 	withShared $ liftIO . go
   where
@@ -65,7 +67,7 @@ setAnnexPerm' modef isdir file = unlessM crippledFileSystem $
 			modifyFileMode file $ f []
 	modef' = fromMaybe addModes modef
 
-resetAnnexFilePerm :: FilePath -> Annex ()
+resetAnnexFilePerm :: RawFilePath -> Annex ()
 resetAnnexFilePerm = resetAnnexPerm False
 
 {- Like setAnnexPerm, but ignores the current mode of the file entirely,
@@ -76,7 +78,7 @@ resetAnnexFilePerm = resetAnnexPerm False
  - which is going to be moved to a non-temporary location and needs
  - usual modes.
  -}
-resetAnnexPerm :: Bool -> FilePath -> Annex ()
+resetAnnexPerm :: Bool -> RawFilePath -> Annex ()
 resetAnnexPerm isdir file = unlessM crippledFileSystem $ do
 	defmode <- liftIO defaultFileMode
 	let modef moremodes _oldmode = addModes moremodes defmode
@@ -97,13 +99,13 @@ annexFileMode = withShared $ return . go
 {- Creates a directory inside the gitAnnexDir, creating any parent
  - directories up to and including the gitAnnexDir.
  - Makes directories with appropriate permissions. -}
-createAnnexDirectory :: FilePath -> Annex ()
+createAnnexDirectory :: RawFilePath -> Annex ()
 createAnnexDirectory dir = do
-	top <- parentDir . fromRawFilePath <$> fromRepo gitAnnexDir
+	top <- parentDir <$> fromRepo gitAnnexDir
 	createDirectoryUnder' top dir createdir
   where
 	createdir p = do
-		liftIO $ createDirectory p
+		liftIO $ R.createDirectory p
 		setAnnexDirPerm p
 
 {- Create a directory in the git work tree, creating any parent
@@ -111,10 +113,10 @@ createAnnexDirectory dir = do
  -
  - Uses default permissions.
  -}
-createWorkTreeDirectory :: FilePath -> Annex ()
+createWorkTreeDirectory :: RawFilePath -> Annex ()
 createWorkTreeDirectory dir = do
 	fromRepo repoWorkTree >>= liftIO . \case
-		Just wt -> createDirectoryUnder (fromRawFilePath wt) dir
+		Just wt -> createDirectoryUnder wt dir
 		-- Should never happen, but let whatever tries to write
 		-- to the directory be what throws an exception, as that
 		-- will be clearer than an exception from here.
@@ -129,7 +131,7 @@ createWorkTreeDirectory dir = do
  - shared repository, the current user may not be able to change a file
  - owned by another user, so failure to set this mode is ignored.
  -}
-freezeContent :: FilePath -> Annex ()
+freezeContent :: RawFilePath -> Annex ()
 freezeContent file = unlessM crippledFileSystem $
 	withShared go
   where
@@ -141,7 +143,7 @@ freezeContent file = unlessM crippledFileSystem $
 		removeModes writeModes .
 		addModes [ownerReadMode]
 
-isContentWritePermOk :: FilePath -> Annex Bool
+isContentWritePermOk :: RawFilePath -> Annex Bool
 isContentWritePermOk file = ifM crippledFileSystem
 	( return True
 	, withShared go
@@ -151,12 +153,12 @@ isContentWritePermOk file = ifM crippledFileSystem
 	go AllShared = want writeModes
 	go _ = return True
 	want wantmode =
-		liftIO (catchMaybeIO $ fileMode <$> getFileStatus file) >>= return . \case
+		liftIO (catchMaybeIO $ fileMode <$> R.getFileStatus file) >>= return . \case
 			Nothing -> True
 			Just havemode -> havemode == combineModes (havemode:wantmode)
 
 {- Adjusts read mode of annexed file per core.sharedRepository setting. -}
-chmodContent :: FilePath -> Annex ()
+chmodContent :: RawFilePath -> Annex ()
 chmodContent file = unlessM crippledFileSystem $
 	withShared go
   where
@@ -169,7 +171,7 @@ chmodContent file = unlessM crippledFileSystem $
 
 {- Allows writing to an annexed file that freezeContent was called on
  - before. -}
-thawContent :: FilePath -> Annex ()
+thawContent :: RawFilePath -> Annex ()
 thawContent file = thawPerms $ withShared go
   where
 	go GroupShared = liftIO $ void $ tryIO $ groupWriteRead file
@@ -190,7 +192,7 @@ thawPerms a = ifM crippledFileSystem
  - is set, this is not done, since the group must be allowed to delete the
  - file.
  -}
-freezeContentDir :: FilePath -> Annex ()
+freezeContentDir :: RawFilePath -> Annex ()
 freezeContentDir file = unlessM crippledFileSystem $
 	withShared go
   where
@@ -199,14 +201,15 @@ freezeContentDir file = unlessM crippledFileSystem $
 	go AllShared = liftIO $ void $ tryIO $ groupWriteRead dir
 	go _ = liftIO $ preventWrite dir
 
-thawContentDir :: FilePath -> Annex ()
-thawContentDir file = thawPerms $ liftIO $ allowWrite $ parentDir file
+thawContentDir :: RawFilePath -> Annex ()
+thawContentDir file = 
+	thawPerms $ liftIO $ allowWrite $ parentDir file
 
 {- Makes the directory tree to store an annexed file's content,
  - with appropriate permissions on each level. -}
-createContentDir :: FilePath -> Annex ()
+createContentDir :: RawFilePath -> Annex ()
 createContentDir dest = do
-	unlessM (liftIO $ doesDirectoryExist dir) $
+	unlessM (liftIO $ R.doesPathExist dir) $
 		createAnnexDirectory dir 
 	-- might have already existed with restricted perms
 	unlessM crippledFileSystem $
@@ -217,7 +220,7 @@ createContentDir dest = do
 {- Creates the content directory for a file if it doesn't already exist,
  - or thaws it if it does, then runs an action to modify the file, and
  - finally, freezes the content directory. -}
-modifyContent :: FilePath -> Annex a -> Annex a
+modifyContent :: RawFilePath -> Annex a -> Annex a
 modifyContent f a = do
 	createContentDir f -- also thaws it
 	v <- tryNonAsync a
