@@ -38,12 +38,12 @@ import Config
  -}
 pidLockChildProcess
 	:: FilePath
-	-> [String]
+	-> [CommandParam]
 	-> (CreateProcess -> CreateProcess)
 	-> (Maybe Handle -> Maybe Handle -> Maybe Handle -> ProcessHandle -> IO a)
 	-> Annex a
 pidLockChildProcess cmd ps f a = do
-	let p = f (proc cmd ps)
+	let p = f (proc cmd (toCommand ps))
 	let gonopidlock = withCreateProcess p a
 #ifndef mingw32_HOST_OS
 	pidLockFile >>= liftIO . \case
@@ -75,7 +75,7 @@ pidLockChildProcess cmd ps f a = do
  -
  - This is like pidLockChildProcess, but rather than running a process
  - itself, it runs the action with a modified Annex state that passes the
- - necessary env var.
+ - necessary env var when running git.
  -}
 runsGitAnnexChildProcessViaGit :: Annex a -> Annex a
 #ifndef mingw32_HOST_OS
