@@ -6,6 +6,8 @@
  - Licensed under the GNU AGPL version 3 or higher.
  -}
 
+{-# LANGUAGE CPP #-}
+
 module Annex.Url (
 	withUrlOptions,
 	withUrlOptionsPromptingCreds,
@@ -14,6 +16,7 @@ module Annex.Url (
 	ipAddressesUnlimited,
 	checkBoth,
 	download,
+	download',
 	exists,
 	getUrlInfo,
 	U.downloadQuiet,
@@ -33,7 +36,11 @@ import Annex.Common
 import qualified Annex
 import qualified Utility.Url as U
 import Utility.IPAddress
+#ifdef WITH_HTTP_CLIENT_RESTRICTED
+import Network.HTTP.Client.Restricted
+#else
 import Utility.HttpManagerRestricted
+#endif
 import Utility.Metered
 import Git.Credential
 import qualified BuildInfo
@@ -172,14 +179,14 @@ download meterupdate url file uo =
 		Right () -> return True
 		Left err -> warning err >> return False
 
+download' :: MeterUpdate -> U.URLString -> FilePath -> U.UrlOptions -> Annex (Either String ())
+download' meterupdate url file uo =
+	liftIO (U.download meterupdate url file uo)
+
 exists :: U.URLString -> U.UrlOptions -> Annex Bool
 exists url uo = liftIO (U.exists url uo) >>= \case
 	Right b -> return b
 	Left err -> warning err >> return False
 
-getUrlInfo :: U.URLString -> U.UrlOptions -> Annex U.UrlInfo
-getUrlInfo url uo = liftIO (U.getUrlInfo url uo) >>= \case
-	Right i -> return i
-	Left err -> do
-		warning err
-		return $ U.UrlInfo False Nothing Nothing
+getUrlInfo :: U.URLString -> U.UrlOptions -> Annex (Either String U.UrlInfo)
+getUrlInfo url uo = liftIO (U.getUrlInfo url uo)
