@@ -163,11 +163,11 @@ combineViewFilter old@(ExcludeValues olds) (ExcludeValues news)
 combineViewFilter (FilterValues _) newglob@(FilterGlob _) =
 	(newglob, Widening)
 combineViewFilter (FilterGlob oldglob) new@(FilterValues s)
-	| all (matchGlob (compileGlob oldglob CaseInsensative) . decodeBS . fromMetaValue) (S.toList s) = (new, Narrowing)
+	| all (matchGlob (compileGlob oldglob CaseInsensative (GlobFilePath False)) . decodeBS . fromMetaValue) (S.toList s) = (new, Narrowing)
 	| otherwise = (new, Widening)
 combineViewFilter (FilterGlob old) newglob@(FilterGlob new)
 	| old == new = (newglob, Unchanged)
-	| matchGlob (compileGlob old CaseInsensative) new = (newglob, Narrowing)
+	| matchGlob (compileGlob old CaseInsensative (GlobFilePath False)) new = (newglob, Narrowing)
 	| otherwise = (newglob, Widening)
 combineViewFilter (FilterGlob _) new@(ExcludeValues _) = (new, Narrowing)
 combineViewFilter (ExcludeValues _) new@(FilterGlob _) = (new, Widening)
@@ -216,7 +216,7 @@ viewComponentMatcher viewcomponent = \metadata ->
 		FilterValues s -> \values -> setmatches $
 			S.intersection s values
 		FilterGlob glob ->
-			let cglob = compileGlob glob CaseInsensative
+			let cglob = compileGlob glob CaseInsensative (GlobFilePath False)
 			in \values -> setmatches $
 				S.filter (matchGlob cglob . decodeBS . fromMetaValue) values
 		ExcludeValues excludes -> \values -> 
@@ -253,7 +253,8 @@ toViewPath = escapepseudo [] . decodeBS . fromMetaValue
 		| [c1,c2,c3] == pseudoBackslash = escapepseudo ("%":pseudoBackslash:s) cs
 		| [c1,c2,c3] == pseudoColon = escapepseudo ("%":pseudoColon:s) cs
 		| otherwise = escapepseudo ([c1]:s) (c2:c3:cs)
-	escapepseudo s cs = concat (reverse (cs:s))
+	escapepseudo s (c:cs) = escapepseudo ([c]:s) cs
+	escapepseudo s [] = concat (reverse s)
 
 fromViewPath :: FilePath -> MetaValue
 fromViewPath = toMetaValue . encodeBS . deescapepseudo []
