@@ -17,6 +17,9 @@ module Annex.View.ViewedFile (
 ) where
 
 import Annex.Common
+import Utility.QuickCheck
+
+import qualified Data.ByteString as S
 
 type FileName = String
 type ViewedFile = FileName
@@ -34,14 +37,14 @@ type MkViewedFile = FilePath -> ViewedFile
  -}
 viewedFileFromReference :: MkViewedFile
 viewedFileFromReference f = concat
-	[ escape base
+	[ escape (fromRawFilePath base)
 	, if null dirs then "" else "_%" ++ intercalate "%" (map escape dirs) ++ "%"
-	, escape $ concat extensions
+	, escape $ fromRawFilePath $ S.concat extensions
 	]
   where
 	(path, basefile) = splitFileName f
 	dirs = filter (/= ".") $ map dropTrailingPathSeparator (splitPath path)
-	(base, extensions) = splitShortExtensions basefile
+	(base, extensions) = splitShortExtensions (toRawFilePath basefile)
 
 	{- To avoid collisions with filenames or directories that contain
 	 - '%', and to allow the original directories to be extracted
@@ -76,11 +79,12 @@ dirFromViewedFile = joinPath . drop 1 . sep [] ""
 			[] -> sep l curr cs
 		| otherwise = sep l (c:curr) cs
 
-prop_viewedFile_roundtrips :: FilePath -> Bool
-prop_viewedFile_roundtrips f
+prop_viewedFile_roundtrips :: TestableFilePath -> Bool
+prop_viewedFile_roundtrips tf
 	-- Relative filenames wanted, not directories.
 	| any (isPathSeparator) (end f ++ beginning f) = True
-	| isAbsolute f = True
+	| isAbsolute f || isDrive f = True
 	| otherwise = dir == dirFromViewedFile (viewedFileFromReference f)
   where
+	f = fromTestableFilePath tf
 	dir = joinPath $ beginning $ splitDirectories f
