@@ -62,7 +62,8 @@ import System.Log.Logger
 import Network.Socket (HostName)
 
 stopDaemon :: Annex ()
-stopDaemon = liftIO . Utility.Daemon.stopDaemon =<< fromRepo gitAnnexPidFile
+stopDaemon = liftIO . Utility.Daemon.stopDaemon . fromRawFilePath
+	=<< fromRepo gitAnnexPidFile
 
 {- Starts the daemon. If the daemon is run in the foreground, once it's
  - running, can start the browser.
@@ -74,25 +75,25 @@ startDaemon assistant foreground startdelay cannotrun listenhost startbrowser =
 	Annex.changeState $ \s -> s { Annex.daemon = True }
 	enableInteractiveBranchAccess
 	pidfile <- fromRepo gitAnnexPidFile
-	logfile <- fromRepo gitAnnexLogFile
-	liftIO $ debugM desc $ "logging to " ++ logfile
+	logfile <- fromRepo gitAnnexDaemonLogFile
+	liftIO $ debugM desc $ "logging to " ++ fromRawFilePath logfile
 	createAnnexDirectory (parentDir pidfile)
 #ifndef mingw32_HOST_OS
 	createAnnexDirectory (parentDir logfile)
-	logfd <- liftIO $ handleToFd =<< openLog logfile
+	logfd <- liftIO $ handleToFd =<< openLog (fromRawFilePath logfile)
 	if foreground
 		then do
 			origout <- liftIO $ catchMaybeIO $ 
 				fdToHandle =<< dup stdOutput
 			origerr <- liftIO $ catchMaybeIO $ 
 				fdToHandle =<< dup stdError
-			let undaemonize = Utility.Daemon.foreground logfd (Just pidfile)
+			let undaemonize = Utility.Daemon.foreground logfd (Just (fromRawFilePath pidfile))
 			start undaemonize $ 
 				case startbrowser of
 					Nothing -> Nothing
 					Just a -> Just $ a origout origerr
 		else
-			start (Utility.Daemon.daemonize logfd (Just pidfile) False) Nothing
+			start (Utility.Daemon.daemonize logfd (Just (fromRawFilePath pidfile)) False) Nothing
 #else
 	-- Windows doesn't daemonize, but does redirect output to the
 	-- log file. The only way to do so is to restart the program.
@@ -101,7 +102,7 @@ startDaemon assistant foreground startdelay cannotrun listenhost startbrowser =
 		createAnnexDirectory (parentDir logfile)
 		ifM (liftIO $ isNothing <$> getEnv flag)
 			( liftIO $ withNullHandle $ \nullh -> do
-				loghandle <- openLog logfile
+				loghandle <- openLog (fromRawFilePath logfile)
 				e <- getEnvironment
 				cmd <- programPath
 				ps <- getArgs
@@ -114,7 +115,7 @@ startDaemon assistant foreground startdelay cannotrun listenhost startbrowser =
 				exitcode <- withCreateProcess p $ \_ _ _ pid ->
 					waitForProcess pid
 				exitWith exitcode
-			, start (Utility.Daemon.foreground (Just pidfile)) $
+			, start (Utility.Daemon.foreground (Just (fromRawFilePath pidfile))) $
 				case startbrowser of
 					Nothing -> Nothing
 					Just a -> Just $ a Nothing Nothing
@@ -127,8 +128,8 @@ startDaemon assistant foreground startdelay cannotrun listenhost startbrowser =
 	start daemonize webappwaiter = withThreadState $ \st -> do
 		checkCanWatch
 		dstatus <- startDaemonStatus
-		logfile <- fromRepo gitAnnexLogFile
-		liftIO $ debugM desc $ "logging to " ++ logfile
+		logfile <- fromRepo gitAnnexDaemonLogFile
+		liftIO $ debugM desc $ "logging to " ++ fromRawFilePath logfile
 		liftIO $ daemonize $
 			flip runAssistant (go webappwaiter) 
 				=<< newAssistantData st dstatus
