@@ -56,7 +56,9 @@ calcSyncRemotes = do
 	let syncable = filter good rs
 	contentremotes <- filterM (not <$$> liftIO . getDynamicConfig . remoteAnnexIgnore . Remote.gitconfig) $
 		filter (\r -> Remote.uuid r /= NoUUID) syncable
-	let (exportremotes, dataremotes) = partition (exportTree . Remote.config) contentremotes
+	let (exportremotes, nonexportremotes) = partition (exportTree . Remote.config) contentremotes
+	let isimport r = importTree (Remote.config r) || Remote.thirdPartyPopulated (Remote.remotetype r)
+	let dataremotes = filter (not . isimport) nonexportremotes
 
 	return $ \dstatus -> dstatus
 		{ syncRemotes = syncable
