@@ -51,7 +51,8 @@ ensureInstalled = ifM (isJust <$> getEnv "GIT_ANNEX_PACKAGE_INSTALL")
 	go (Just base) = do
 		let program = base </> "git-annex"
 		programfile <- programFile
-		createDirectoryIfMissing True (parentDir programfile)
+		createDirectoryIfMissing True $
+			fromRawFilePath (parentDir (toRawFilePath programfile))
 		writeFile programfile program
 
 #ifdef darwin_HOST_OS
@@ -100,9 +101,10 @@ installWrapper :: FilePath -> String -> IO ()
 installWrapper file content = do
 	curr <- catchDefaultIO "" $ readFileStrict file
 	when (curr /= content) $ do
-		createDirectoryIfMissing True (parentDir file)
+		createDirectoryIfMissing True (fromRawFilePath (parentDir (toRawFilePath file)))
 		viaTmp writeFile file content
-		modifyFileMode file $ addModes [ownerExecuteMode]
+		modifyFileMode (toRawFilePath file) $ 
+			addModes [ownerExecuteMode]
 
 installFileManagerHooks :: FilePath -> IO ()
 #ifdef linux_HOST_OS
@@ -131,7 +133,7 @@ installFileManagerHooks program = unlessM osAndroid $ do
 	scriptname action = "git-annex " ++ action
 	installscript f c = whenM (safetoinstallscript f) $ do
 		writeFile f c
-		modifyFileMode f $ addModes [ownerExecuteMode]
+		modifyFileMode (toRawFilePath f) $ addModes [ownerExecuteMode]
 	safetoinstallscript f = catchDefaultIO True $
 		elem autoaddedcomment . lines <$> readFileStrict f
 	autoaddedcomment = "# " ++ autoaddedmsg ++ " (To disable, chmod 600 this file.)"
