@@ -10,9 +10,15 @@
 
 module Assistant.Install.Menu where
 
-import Common
-
 import Utility.FreeDesktop
+import Utility.FileSystemEncoding
+import Utility.Path
+
+import System.IO
+import Utility.SystemDirectory
+#ifndef darwin_HOST_OS
+import System.FilePath
+#endif
 
 installMenu :: FilePath -> FilePath -> FilePath -> FilePath -> IO ()
 #ifdef darwin_HOST_OS
@@ -39,7 +45,7 @@ fdoDesktopMenu command = genDesktopEntry
 
 installIcon :: FilePath -> FilePath -> IO ()
 installIcon src dest = do
-	createDirectoryIfMissing True (parentDir dest)
+	createDirectoryIfMissing True (fromRawFilePath (parentDir (toRawFilePath dest)))
 	withBinaryFile src ReadMode $ \hin ->
 		withBinaryFile dest WriteMode $ \hout ->
 			hGetContents hin >>= hPutStr hout
