@@ -30,6 +30,7 @@ import qualified Data.Text as T
 #endif
 import qualified Utility.Lsof as Lsof
 import Utility.ThreadScheduler
+import qualified Utility.RawFilePath as R
 
 import Control.Concurrent.Async
 
@@ -91,10 +92,10 @@ runRepair u mrmt destructiverepair = do
 	remoterepair fsckresults = case Remote.repairRepo =<< mrmt of
 		Nothing -> return False
 		Just mkrepair -> do
-			thisrepopath <- liftIO . absPath . fromRawFilePath
+			thisrepopath <- liftIO . absPath
 				=<< liftAnnex (fromRepo Git.repoPath)
 			a <- liftAnnex $ mkrepair $
-				repair fsckresults (Just thisrepopath)
+				repair fsckresults (Just (fromRawFilePath thisrepopath))
 			liftIO $ catchBoolIO a
 
 	repair fsckresults referencerepo = do
@@ -140,7 +141,8 @@ repairStaleGitLocks r = do
 repairStaleLocks :: [FilePath] -> Assistant ()
 repairStaleLocks lockfiles = go =<< getsizes
   where
-	getsize lf = catchMaybeIO $ (\s -> (lf, s)) <$> getFileSize lf
+	getsize lf = catchMaybeIO $ (\s -> (lf, s))
+		<$> getFileSize (toRawFilePath lf)
 	getsizes = liftIO $ catMaybes <$> mapM getsize lockfiles
 	go [] = return ()
 	go l = ifM (liftIO $ null <$> Lsof.query ("--" : map fst l))
@@ -148,7 +150,7 @@ repairStaleLocks lockfiles = go =<< getsizes
 			waitforit "to check stale git lock file"
 			l' <- getsizes
 			if l' == l
-				then liftIO $ mapM_ nukeFile (map fst l)
+				then liftIO $ mapM_ (removeWhenExistsWith R.removeLink . toRawFilePath . fst) l
 				else go l'
 		, do
 			waitforit "for git lock file writer"
