@@ -244,10 +244,11 @@ genSshKeyPair = withTmpDir "git-annex-keygen" $ \dir -> do
 installSshKeyPair :: SshKeyPair -> SshData -> IO SshData
 installSshKeyPair sshkeypair sshdata = do
 	sshdir <- sshDir
-	createDirectoryIfMissing True $ parentDir $ sshdir </> sshPrivKeyFile sshdata
+	createDirectoryIfMissing True $ fromRawFilePath $
+		parentDir $ toRawFilePath $ sshdir </> sshPrivKeyFile sshdata
 
 	unlessM (doesFileExist $ sshdir </> sshPrivKeyFile sshdata) $
-		writeFileProtected (sshdir </> sshPrivKeyFile sshdata) (sshPrivKey sshkeypair)
+		writeFileProtected (toRawFilePath (sshdir </> sshPrivKeyFile sshdata)) (sshPrivKey sshkeypair)
 	unlessM (doesFileExist $ sshdir </> sshPubKeyFile sshdata) $
 		writeFile (sshdir </> sshPubKeyFile sshdata) (sshPubKey sshkeypair)
 
@@ -330,7 +331,7 @@ setSshConfig sshdata config = do
 			, "Host " ++ mangledhost
 			] ++ map (\(k, v) -> "\t" ++ k ++ " " ++ v)
 				(settings ++ config)
-		setSshConfigMode configfile
+		setSshConfigMode (toRawFilePath configfile)
 
 	return $ sshdata
 		{ sshHostName = T.pack mangledhost
