@@ -17,13 +17,12 @@ import Assistant.DaemonStatus
 import Assistant.ScanRemotes
 import Assistant.RemoteControl
 import qualified Command.Sync
-import Utility.Parallel
 import qualified Git
 import qualified Git.Command
 import qualified Remote
 import qualified Types.Remote as Remote
-import qualified Remote.List as Remote
 import qualified Annex.Branch
+import Remote.List.Util
 import Annex.UUID
 import Annex.TaggedPush
 import Annex.Ssh
@@ -43,6 +42,7 @@ import Database.Export
 import Data.Time.Clock
 import qualified Data.Map as M
 import Control.Concurrent
+import Control.Concurrent.Async
 
 {- Syncs with remotes that may have been disconnected for a while.
  - 
@@ -177,6 +177,11 @@ parallelPush g rs a = do
 		<*> (Remote.getRepo r >>= \repo ->
 			sshOptionsTo repo (Remote.gitconfig r) g)
 
+inParallel :: (v -> IO Bool) -> [v] -> IO ([v], [v])
+inParallel a l = (\(t,f) -> (map fst t, map fst f)) 
+	. partition snd 
+	. zip l <$> mapConcurrently a l
+
 {- Displays an alert while running an action that syncs with some remotes,
  - and returns any remotes that it failed to sync with.
  -
@@ -216,7 +221,8 @@ manualPull currentbranch remotes = do
 				, return $ Just r
 				)
 		else return Nothing
-	haddiverged <- liftAnnex Annex.Branch.forceUpdate
+	haddiverged <- Annex.Branch.refsWereMerged
+		<$> liftAnnex Annex.Branch.forceUpdate
 	forM_ remotes $ \r ->
 		liftAnnex $ Command.Sync.mergeRemote r
 			currentbranch Command.Sync.mergeConfig def
@@ -267,7 +273,7 @@ changeSyncFlag r enabled = do
 	repo <- Remote.getRepo r
 	let key = Config.remoteAnnexConfig repo "sync"
 	Config.setConfig key (boolConfig enabled)
-	void Remote.remoteListRefresh
+	remotesChanged
 
 updateExportTreeFromLogAll :: Assistant ()
 updateExportTreeFromLogAll = do
