@@ -58,7 +58,7 @@ checkCanWatch
 	| canWatch = do
 #ifndef mingw32_HOST_OS
 		liftIO Lsof.setup
-		unlessM (liftIO (inPath "lsof") <||> Annex.getState Annex.force)
+		unlessM (liftIO (inSearchPath "lsof") <||> Annex.getState Annex.force)
 			needLsof
 #else
 		noop
@@ -198,7 +198,7 @@ add :: GetFileMatcher -> FilePath -> Assistant (Maybe Change)
 add largefilematcher file = ifM (liftAnnex $ checkFileMatcher largefilematcher (toRawFilePath file))
 	( pendingAddChange file
 	, do
-		liftAnnex $ Annex.Queue.addCommand "add"
+		liftAnnex $ Annex.Queue.addCommand [] "add"
 			[Param "--force", Param "--"] [file]
 		madeChange file AddFileChange
 	)
