@@ -16,14 +16,15 @@ import Assistant.WebApp.Common
 import qualified Annex
 import qualified Git
 import Config
-import Config.Files
+import Config.Files.AutoStart
 import Annex.NumCopies
 import Utility.DataUnits
 import Git.Config
 import Types.Distribution
-import qualified BuildInfo
+import Assistant.Upgrade
 
 import qualified Data.Text as T
+import qualified System.FilePath.ByteString as P
 
 data PrefsForm = PrefsForm
 	{ diskReserve :: Text
@@ -58,7 +59,7 @@ prefsAForm d = PrefsForm
 		, ("disabled", NoAutoUpgrade)
 		]
 	autoUpgradeLabel
-		| isJust BuildInfo.upgradelocation = "Auto upgrade"
+		| upgradeSupported = "Auto upgrade"
 		| otherwise = "Auto restart on upgrade"
 
 	positiveIntField = check isPositive intField
@@ -118,5 +119,6 @@ postPreferencesR = page "Preferences" (Just Configuration) $ do
 
 inAutoStartFile :: Annex Bool
 inAutoStartFile = do
-	here <- liftIO . absPath . fromRawFilePath =<< fromRepo Git.repoPath
-	any (`equalFilePath` here) <$> liftIO readAutoStartFile
+	here <- liftIO . absPath =<< fromRepo Git.repoPath
+	any (`P.equalFilePath` here) . map toRawFilePath
+		<$> liftIO readAutoStartFile
