@@ -11,8 +11,8 @@ module Assistant.WebApp.Documentation where
 
 import Assistant.WebApp.Common
 import Assistant.Install (standaloneAppBase)
-import Build.SysConfig (packageversion)
-import BuildInfo
+import BuildInfo (packageversion)
+import BuildFlags
 
 {- The full license info may be included in a file on disk that can
  - be read in and displayed. -}
