@@ -23,7 +23,7 @@ tests =
 	, testCp "cp_a" "-a"
 	, testCp "cp_p" "-p"
 	, testCp "cp_preserve_timestamps" "--preserve=timestamps"
-	, testCp "cp_reflink_auto" "--reflink=auto"
+	, testCp "cp_reflink_supported" "--reflink=auto"
 	, TestCase "xargs -0" $ testCmd "xargs_0" "xargs -0 </dev/null"
 	, TestCase "rsync" $ testCmd "rsync" "rsync --version >/dev/null"
 	, TestCase "curl" $ testCmd "curl" "curl --version >/dev/null"
@@ -62,7 +62,7 @@ getGitVersion = go =<< getEnv "FORCE_GIT_VERSION"
 	go (Just s) = return $ Config "gitversion" $ StringConfig s
 	go Nothing = do
 		v <- Git.Version.installed
-		let oldestallowed = Git.Version.normalize "1.7.1.0"
+		let oldestallowed = Git.Version.normalize "2.1"
 		when (v < oldestallowed) $
 			error $ "installed git version " ++ show v ++ " is too old! (Need " ++ show oldestallowed ++ " or newer)"
 		return $ Config "gitversion" $ StringConfig $ show v
@@ -83,20 +83,6 @@ run :: [TestCase] -> IO ()
 run ts = do
 	setup
 	config <- runTests ts
-	v <- getEnv "CROSS_COMPILE"
-	case v of
-		Just "Android" -> writeSysConfig $ androidConfig config
-		_ -> writeSysConfig config
+	writeSysConfig config
 	writeVersion =<< getVersion
 	cleanup
-
-{- Hard codes some settings to cross-compile for Android. -}
-androidConfig :: [Config] -> [Config]
-androidConfig c = overrides ++ filter (not . overridden) c
-  where
-	overrides = 
-		[ Config "cp_reflink_auto" $ BoolConfig False
-		, Config "curl" $ BoolConfig False
-		]
-	overridden (Config k _) = k `elem` overridekeys
-	overridekeys = map (\(Config k _) -> k) overrides
