@@ -9,11 +9,17 @@
  - for that.
  - 
  - To build the installer, git-annex should already be built to
- - ./git-annex.exe and the necessary utility programs
- - (specifically rsync)
- - already installed in PATH from msys32.
+ - ./git-annex.exe, then run this program, using eg:
  -
- - Copyright 2013-2015 Joey Hess <id@joeyh.name>
+ - stack ghc --no-haddock --package nsis Build/NullSoftInstaller.hs
+ -
+ - A build of libmagic will also be included in the installer, if its files
+ - are found in the current directory: 
+ -   ./magic.mgc ./libmagic-1.dll ./libgnurx-0.dll
+ - To build git-annex to usse libmagic, it has to be built with the
+ - magicmime build flag turned on.
+ -
+ - Copyright 2013-2020 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU AGPL version 3 or higher.
  -}
@@ -42,6 +48,8 @@ main = do
 	withTmpDir "nsis-build" $ \tmpdir -> do
 		let gitannex = tmpdir </> gitannexprogram
 		mustSucceed "ln" [File "git-annex.exe", File gitannex]
+		magicDLLs' <- installwhenpresent magicDLLs tmpdir
+		magicShare' <- installwhenpresent magicShare tmpdir
 		let license = tmpdir </> licensefile
 		mustSucceed "sh" [Param "-c", Param $ "zcat standalone/licences.gz > '" ++ license ++ "'"]
 		webappscript <- vbsLauncher tmpdir "git-annex-webapp" "git annex webapp"
@@ -51,7 +59,7 @@ main = do
 		let gitannexcmd = tmpdir </> "git-annex.cmd"
 		writeFile gitannexcmd "git annex %*"
 		writeFile nsifile $ makeInstaller
-			gitannex gitannexcmd license htmlhelp winPrograms
+			gitannex gitannexcmd license htmlhelp (winPrograms ++ magicDLLs') magicShare'
 			[ webappscript, autostartscript ]
 		mustSucceed "makensis" [File nsifile]
 	removeFile nsifile -- left behind if makensis fails
@@ -62,6 +70,15 @@ main = do
 		case r of
 			True -> return ()
 			False -> error $ cmd ++ " failed"
+	installwhenpresent fs tmpdir = do
+		fs' <- forM fs $ \f -> do
+			present <- doesFileExist f
+			if present
+				then do
+					mustSucceed "ln" [File f, File (tmpdir </> f)]
+					return (Just f)
+				else return Nothing
+		return (catMaybes fs')
 
 {- Generates a .vbs launcher which runs a command without any visible DOS
  - box. It expects to be passed the directory where git-annex is installed. -}
@@ -117,8 +134,8 @@ needGit = strConcat
 	, fromString "You can install git from http:////git-scm.com//"
 	]
 
-makeInstaller :: FilePath -> FilePath -> FilePath -> FilePath -> [FilePath] -> [FilePath] -> String
-makeInstaller gitannex gitannexcmd license htmlhelp extrabins launchers = nsis $ do
+makeInstaller :: FilePath -> FilePath -> FilePath -> FilePath -> [FilePath] -> [FilePath] -> [FilePath] -> String
+makeInstaller gitannex gitannexcmd license htmlhelp extrabins sharefiles launchers = nsis $ do
 	name "git-annex"
 	outFile $ str installer
 	{- Installing into the same directory as git avoids needing to modify
@@ -163,6 +180,8 @@ makeInstaller gitannex gitannexcmd license htmlhelp extrabins launchers = nsis $
 		-- there.
 		setOutPath "$INSTDIR\\usr\\bin"
 		mapM_ addfile (gitannex:extrabins)
+		setOutPath "$INSTDIR\\usr\\share\\misc"
+		mapM_ addfile sharefiles
 		-- This little wrapper is installed in the cmd directory,
 		-- so that "git-annex" works (as well as "git annex"),
 		-- when only that directory is in PATH (ie, in a ms-dos
