@@ -9,6 +9,7 @@ module Build.OSXMkLibs (mklibs) where
 
 import Data.Maybe
 import System.FilePath
+import System.IO
 import Control.Monad
 import Control.Monad.IfElse
 import Data.List
@@ -88,7 +89,12 @@ otool appbase installedbins replacement_libs libmap = do
 	files <- filterM doesFileExist =<< dirContentsRecursive appbase
 	process [] files replacement_libs libmap
   where
-	want s = not ("@executable_path" `isInfixOf` s)
+	want s = 
+		-- This seems to be about finding libraries next
+		-- to executables or something. May need further resolving
+		-- to find real path to library, but for now, skip it.
+		not ("@executable_path" `isInfixOf` s)
+		&& not ("@loader_path" `isInfixOf` s)
 		-- OSX framekworks such as Cocoa are too tightly tied to
 		-- a specific OSX version, so don't bundle.
 		&& not (".framework" `isInfixOf` s)
