@@ -5,6 +5,8 @@
  - Licensed under the GNU AGPL version 3 or higher.
  -}
 
+{-# LANGUAGE OverloadedStrings #-}
+
 module Command.AddUnused where
 
 import Logs.Location
@@ -28,10 +30,12 @@ start = startUnused "addunused" perform
 perform :: Key -> CommandPerform
 perform key = next $ do
 	logStatus key InfoPresent
-	addLink file key Nothing
+	-- Ignore the usual git ignores because the user has explictly
+	-- asked to add these files.
+	addLink (CheckGitIgnore False) file key Nothing
 	return True
   where
-	file = "unused." ++ fromRawFilePath (keyFile key)
+	file = "unused." <> keyFile key
 
 {- The content is not in the annex, but in another directory, and
  - it seems better to error out, rather than moving bad/tmp content into
