@@ -10,6 +10,7 @@ module Command.Commit where
 import Command
 import qualified Annex.Branch
 import qualified Git
+import Git.Types
 
 cmd :: Command
 cmd = command "commit" SectionPlumbing 
@@ -20,10 +21,12 @@ seek :: CmdParams -> CommandSeek
 seek = withNothing (commandAction start)
 
 start :: CommandStart
-start = starting "commit" (ActionItemOther (Just "git-annex")) $ do
-		Annex.Branch.commit =<< Annex.Branch.commitMessage
-		_ <- runhook <=< inRepo $ Git.hookPath "annex-content"
-		next $ return True
+start = starting "commit" ai si $ do
+	Annex.Branch.commit =<< Annex.Branch.commitMessage
+	_ <- runhook <=< inRepo $ Git.hookPath "annex-content"
+	next $ return True
   where
 	runhook (Just hook) = liftIO $ boolSystem hook []
 	runhook Nothing = return True
+	ai = ActionItemOther (Just (fromRef Annex.Branch.name))
+	si = SeekInput []
