@@ -46,7 +46,7 @@ import Control.Concurrent
 cmd :: Command
 cmd = withGlobalOptions [jobsOption, jsonOptions, jsonProgressOption] $
 	command "export" SectionCommon
-		"export content to a remote"
+		"export a tree of files to a special remote"
 		paramTreeish (seek <$$> optParser)
 
 data ExportOptions = ExportOptions
@@ -192,7 +192,7 @@ changeExport r db (PreferredFiltered new) = do
 	-- from a previous export, that are not part of this export.
 	c <- Annex.getState Annex.errcounter
 	when (c == 0) $ do
-		recordExport (uuid r) $ ExportChange
+		recordExportUnderway (uuid r) $ ExportChange
 			{ oldTreeish = exportedTreeishes old
 			, newTreeish = new
 			}
@@ -283,7 +283,11 @@ performExport r db ek af contentsha loc allfilledvar = do
 	sent <- tryNonAsync $ case ek of
 		AnnexKey k -> ifM (inAnnex k)
 			( notifyTransfer Upload af $
-				upload (uuid r) k af stdRetry $ \pm -> do
+				-- alwaysUpload because the same key
+				-- could be used for more than one export
+				-- location, and concurrently uploading
+				-- of the content should still be allowed.
+				alwaysUpload (uuid r) k af Nothing stdRetry $ \pm -> do
 					let rollback = void $
 						performUnexport r db [ek] loc
 					sendAnnex k rollback $ \f ->
@@ -362,10 +366,10 @@ cleanupUnexport r db eks loc = do
 			removeExportedLocation db (asKey ek) loc
 		flushDbQueue db
 
-	-- An appendonly remote can support removeExportLocation to remove
-	-- the file from the exported tree, but still retain the content
-	-- and allow retrieving it.
-	unless (appendonly r) $ do
+	-- An versionedExport remote supports removeExportLocation to remove
+	-- the file from the exported tree, but still retains the content
+	-- and allows retrieving it.
+	unless (versionedExport (exportActions r)) $ do
 		remaininglocs <- liftIO $ 
 			concat <$> forM eks (\ek -> getExportedLocation db (asKey ek))
 		when (null remaininglocs) $
