@@ -73,14 +73,15 @@ seek o = do
   where
 	ww = WarnUnmatchLsFiles
 
-start :: FindOptions -> RawFilePath -> Key -> CommandStart
-start o file key = startingCustomOutput key $ do
-	showFormatted (formatOption o) file $ ("file", fromRawFilePath file) : keyVars key
+start :: FindOptions -> SeekInput -> RawFilePath -> Key -> CommandStart
+start o _ file key = startingCustomOutput key $ do
+	showFormatted (formatOption o) file 
+		(formatVars key (AssociatedFile (Just file)))
 	next $ return True
 
-startKeys :: FindOptions -> (Key, ActionItem) -> CommandStart
-startKeys o (key, ActionItemBranchFilePath (BranchFilePath _ topf) _) = 
-	start o (getTopFilePath topf) key
+startKeys :: FindOptions -> (SeekInput, Key, ActionItem) -> CommandStart
+startKeys o (si, key, ActionItemBranchFilePath (BranchFilePath _ topf) _) = 
+	start o si (getTopFilePath topf) key
 startKeys _ _ = stop
 
 showFormatted :: Maybe Utility.Format.Format -> S.ByteString -> [(String, String)] -> Annex ()
@@ -92,8 +93,9 @@ showFormatted format unformatted vars =
 				Utility.Format.format formatter $
 					M.fromList vars
 
-keyVars :: Key -> [(String, String)]
-keyVars key =
+formatVars :: Key -> AssociatedFile -> [(String, String)]
+formatVars key (AssociatedFile af) =
+	(maybe id (\f l -> (("file", fromRawFilePath f) : l)) af)
 	[ ("key", serializeKey key)
 	, ("backend", decodeBS $ formatKeyVariety $ fromKey keyVariety key)
 	, ("bytesize", size show)
