@@ -9,7 +9,6 @@ module Command.Get where
 
 import Command
 import qualified Remote
-import Annex.Content
 import Annex.Transfer
 import Annex.NumCopies
 import Annex.Wanted
@@ -93,7 +92,7 @@ getKey' key afile = dispatch
   where
 	dispatch [] = do
 		showNote "not available"
-		showlocs
+		showlocs []
 		return False
 	dispatch remotes = notifyTransfer Download afile $ \witness -> do
 		ok <- pickRemote remotes $ \r -> ifM (probablyPresent r)
@@ -104,9 +103,9 @@ getKey' key afile = dispatch
 			then return ok
 			else do
 				Remote.showTriedRemotes remotes
-				showlocs
+				showlocs (map Remote.uuid remotes)
 				return False
-	showlocs = Remote.showLocations False key []
+	showlocs exclude = Remote.showLocations False key exclude
 		"No other repository is known to contain the file."
 	-- This check is to avoid an ugly message if a remote is a
 	-- drive that is not mounted.
@@ -114,10 +113,6 @@ getKey' key afile = dispatch
 		| Remote.hasKeyCheap r =
 			either (const False) id <$> Remote.hasKey r key
 		| otherwise = return True
-	docopy r witness = getViaTmp (Remote.retrievalSecurityPolicy r) (RemoteVerify r) key afile $ \dest ->
-		download (Remote.uuid r) key afile stdRetry
-			(\p -> do
-				showAction $ "from " ++ Remote.name r
-				Remote.verifiedAction $
-					Remote.retrieveKeyFile r key afile (fromRawFilePath dest) p
-			) witness
+	docopy r witness = do
+		showAction $ "from " ++ Remote.name r
+		download r key afile stdRetry witness
