@@ -37,10 +37,10 @@ seek ps = withFilesInGitAnnex ww seeker =<< workTreeItems ww ps
 		, usesLocationLog = False
 		}
 
-start :: RawFilePath -> Key -> CommandStart
-start file key = ifM (isJust <$> isAnnexLink file)
+start :: SeekInput -> RawFilePath -> Key -> CommandStart
+start si file key = ifM (isJust <$> isAnnexLink file)
 	( stop
-	, starting "lock" (mkActionItem (key, file)) $
+	, starting "lock" (mkActionItem (key, file)) si $
 		go =<< liftIO (isPointerFile file)
 	)
   where
@@ -60,26 +60,25 @@ start file key = ifM (isJust <$> isAnnexLink file)
 perform :: RawFilePath -> Key -> CommandPerform
 perform file key = do
 	lockdown =<< calcRepo (gitAnnexLocation key)
-	addLink (fromRawFilePath file) key
+	addLink (CheckGitIgnore False) file key
 		=<< withTSDelta (liftIO . genInodeCache file)
 	next $ cleanup file key
   where
 	lockdown obj = do
 		ifM (isUnmodified key obj)
 			( breakhardlink obj
-			, repopulate (fromRawFilePath obj)
+			, repopulate obj
 			)
 		whenM (liftIO $ R.doesPathExist obj) $
-			freezeContent $ fromRawFilePath obj
+			freezeContent obj
 
 	-- It's ok if the file is hard linked to obj, but if some other
 	-- associated file is, we need to break that link to lock down obj.
 	breakhardlink obj = whenM (catchBoolIO $ (> 1) . linkCount <$> liftIO (R.getFileStatus obj)) $ do
 		mfc <- withTSDelta (liftIO . genInodeCache file)
 		unlessM (sameInodeCache obj (maybeToList mfc)) $ do
-			let obj' = fromRawFilePath obj
-			modifyContent obj' $ replaceGitAnnexDirFile obj' $ \tmp -> do
-				unlessM (checkedCopyFile key obj' tmp Nothing) $
+			modifyContent obj $ replaceGitAnnexDirFile (fromRawFilePath obj) $ \tmp -> do
+				unlessM (checkedCopyFile key obj (toRawFilePath tmp) Nothing) $
 					giveup "unable to lock file"
 			Database.Keys.storeInodeCaches key [obj]
 
@@ -89,10 +88,10 @@ perform file key = do
 		fs <- map (`fromTopFilePath` g)
 			<$> Database.Keys.getAssociatedFiles key
 		mfile <- firstM (isUnmodified key) fs
-		liftIO $ nukeFile obj
+		liftIO $ removeWhenExistsWith R.removeLink obj
 		case mfile of
 			Just unmodified ->
-				unlessM (checkedCopyFile key (fromRawFilePath unmodified) obj Nothing)
+				unlessM (checkedCopyFile key unmodified obj Nothing)
 					lostcontent
 			Nothing -> lostcontent
 
