@@ -64,7 +64,7 @@ runViewer :: FilePath -> [(String, [CommandParam])] -> Annex Bool
 runViewer file [] = do
 	showLongNote $ "left map in " ++ file
 	return True
-runViewer file ((c, ps):rest) = ifM (liftIO $ inPath c)
+runViewer file ((c, ps):rest) = ifM (liftIO $ inSearchPath c)
 	( do
 		showLongNote $ "running: " ++ c ++ unwords (toCommand ps)
 		showOutput
@@ -178,7 +178,7 @@ absRepo reference r
 	| Git.repoIsUrl reference = return $ Git.Construct.localToUrl reference r
 	| Git.repoIsUrl r = return r
 	| otherwise = liftIO $ do
-		r' <- Git.Construct.fromAbsPath =<< absPath (Git.repoPath r)
+		r' <- Git.Construct.fromPath =<< absPath (Git.repoPath r)
 		r'' <- safely $ flip Annex.eval Annex.gitRepo =<< Annex.new r'
 		return (fromMaybe r' r'')
 
