@@ -13,6 +13,7 @@ import qualified Git
 import qualified Git.Branch
 import Annex.CurrentBranch
 import Command.Sync (prepMerge, mergeLocal, mergeConfig, merge, SyncOptions(..))
+import Git.Types
 
 cmd :: Command
 cmd = command "merge" SectionMaintenance
@@ -29,17 +30,23 @@ seek bs = do
 	forM_ bs (commandAction . mergeBranch . Git.Ref . encodeBS')
 
 mergeAnnexBranch :: CommandStart
-mergeAnnexBranch = starting "merge" (ActionItemOther (Just "git-annex")) $ do
+mergeAnnexBranch = starting "merge" ai si $ do
 	_ <- Annex.Branch.update
 	-- commit explicitly, in case no remote branches were merged
 	Annex.Branch.commit =<< Annex.Branch.commitMessage
 	next $ return True
+  where
+	ai = ActionItemOther (Just (fromRef Annex.Branch.name))
+	si = SeekInput []
 
 mergeSyncedBranch :: CommandStart
 mergeSyncedBranch = mergeLocal mergeConfig def =<< getCurrentBranch
 
 mergeBranch :: Git.Ref -> CommandStart
-mergeBranch r = starting "merge" (ActionItemOther (Just (Git.fromRef r))) $ do
+mergeBranch r = starting "merge" ai si $ do
 	currbranch <- getCurrentBranch
 	let o = def { notOnlyAnnexOption = True }
 	next $ merge currbranch mergeConfig o Git.Branch.ManualCommit r
+  where
+	ai = ActionItemOther (Just (Git.fromRef r))
+	si = SeekInput []
