@@ -142,8 +142,7 @@ toPerform dest removewhen key afile fastcheck isthere = do
 		Right False -> logMove srcuuid destuuid False key $ \deststartedwithcopy -> do
 			showAction $ "to " ++ Remote.name dest
 			ok <- notifyTransfer Upload afile $
-				upload (Remote.uuid dest) key afile stdRetry $
-					Remote.action . Remote.storeKey dest key afile
+				upload dest key afile stdRetry
 			if ok
 				then finish deststartedwithcopy $
 					Remote.logStatus dest key InfoPresent
@@ -166,10 +165,10 @@ toPerform dest removewhen key afile fastcheck isthere = do
 			willDropMakeItWorse srcuuid destuuid deststartedwithcopy key afile >>= \case
 				DropAllowed -> drophere setpresentremote contentlock "moved"
 				DropCheckNumCopies -> do
-					numcopies <- getAssociatedFileNumCopies afile
+					(numcopies, mincopies) <- getAssociatedFileNumMinCopies afile
 					(tocheck, verified) <- verifiableCopies key [srcuuid]
 					verifyEnoughCopiesToDrop "" key (Just contentlock)
-						 numcopies [srcuuid] verified
+						 numcopies mincopies [srcuuid] verified
 						 (UnVerifiedRemote dest : tocheck)
 						 (drophere setpresentremote contentlock . showproof)
 						 (faileddrophere setpresentremote)
@@ -208,10 +207,22 @@ fromStart removewhen afile key ai si src =
 			fromPerform src removewhen key afile
 
 fromOk :: Remote -> Key -> Annex Bool
-fromOk src key = do
-	u <- getUUID
-	remotes <- Remote.keyPossibilities key
-	return $ u /= Remote.uuid src && elem src remotes
+fromOk src key
+	-- check if the remote contains the key, when it can be done cheaply
+	| Remote.hasKeyCheap src = 
+		Remote.hasKey src key >>= \case
+			Right True -> return True
+			-- Don't skip getting the key just because the
+			-- remote no longer contains it if the log
+			-- says the remote is supposed to contain it;
+			-- that would be surprising behavior.
+			_ -> checklog
+	| otherwise = checklog
+  where
+	checklog = do
+		u <- getUUID
+		remotes <- Remote.keyPossibilities key
+		return $ u /= Remote.uuid src && elem src remotes
 
 fromPerform :: Remote -> RemoveWhen -> Key -> AssociatedFile -> CommandPerform
 fromPerform src removewhen key afile = do
@@ -223,10 +234,8 @@ fromPerform src removewhen key afile = do
 			then dispatch removewhen deststartedwithcopy True
 			else dispatch removewhen deststartedwithcopy =<< get
   where
-	get = notifyTransfer Download afile $ 
-		download (Remote.uuid src) key afile stdRetry $ \p ->
-			getViaTmp (Remote.retrievalSecurityPolicy src) (RemoteVerify src) key afile $ \t ->
-				Remote.verifiedAction $ Remote.retrieveKeyFile src key afile (fromRawFilePath t) p
+	get = notifyTransfer Download afile $
+		download src key afile stdRetry
 	
 	dispatch _ _ False = stop -- failed
 	dispatch RemoveNever _ True = next $ return True -- copy complete
@@ -235,9 +244,9 @@ fromPerform src removewhen key afile = do
 		willDropMakeItWorse srcuuid destuuid deststartedwithcopy key afile >>= \case
 			DropAllowed -> dropremote "moved"
 			DropCheckNumCopies -> do
-				numcopies <- getAssociatedFileNumCopies afile
+				(numcopies, mincopies) <- getAssociatedFileNumMinCopies afile
 				(tocheck, verified) <- verifiableCopies key [Remote.uuid src]
-				verifyEnoughCopiesToDrop "" key Nothing numcopies [Remote.uuid src] verified
+				verifyEnoughCopiesToDrop "" key Nothing numcopies mincopies [Remote.uuid src] verified
 					tocheck (dropremote . showproof) faileddropremote
 			DropWorse -> faileddropremote		
 	
