@@ -24,6 +24,7 @@ import Utility.AuthToken
 import Utility.Tmp.Dir
 import Utility.FileMode
 import Utility.ThreadScheduler
+import qualified Utility.RawFilePath as R
 import qualified Utility.MagicWormhole as Wormhole
 
 import Control.Concurrent.Async
@@ -98,9 +99,11 @@ genAddresses addrs = do
 
 -- Address is read from stdin, to avoid leaking it in shell history.
 linkRemote :: RemoteName -> CommandStart
-linkRemote remotename = starting "p2p link" (ActionItemOther (Just remotename)) $
+linkRemote remotename = starting "p2p link" ai si $
 	next promptaddr
   where
+	ai = ActionItemOther (Just remotename)
+	si = SeekInput []
 	promptaddr = do
 		liftIO $ putStrLn ""
 		liftIO $ putStr "Enter peer address: "
@@ -124,10 +127,13 @@ linkRemote remotename = starting "p2p link" (ActionItemOther (Just remotename))
 startPairing :: RemoteName -> [P2PAddress] -> CommandStart
 startPairing _ [] = giveup "No P2P networks are currrently available."
 startPairing remotename addrs = ifM (liftIO Wormhole.isInstalled)
-	( starting "p2p pair" (ActionItemOther (Just remotename)) $
+	( starting "p2p pair" ai si $
 		performPairing remotename addrs
 	, giveup "Magic Wormhole is not installed, and is needed for pairing. Install it from your distribution or from https://github.com/warner/magic-wormhole/"
-	) 
+	)
+  where
+	ai = ActionItemOther (Just remotename)
+	si = SeekInput []
 
 performPairing :: RemoteName -> [P2PAddress] -> CommandPerform
 performPairing remotename addrs = do
@@ -215,11 +221,11 @@ wormholePairing remotename ouraddrs ui = do
 	-- to read them. So, set up a temp directory that only
 	-- we can read.
 	withTmpDir "pair" $ \tmp -> do
-		liftIO $ void $ tryIO $ modifyFileMode tmp $ 
+		liftIO $ void $ tryIO $ modifyFileMode (toRawFilePath tmp) $ 
 			removeModes otherGroupModes
 		let sendf = tmp </> "send"
 		let recvf = tmp </> "recv"
-		liftIO $ writeFileProtected sendf $
+		liftIO $ writeFileProtected (toRawFilePath sendf) $
 			serializePairData ourpairdata
 
 		observer <- liftIO Wormhole.mkCodeObserver
@@ -251,7 +257,7 @@ wormholePairing remotename ouraddrs ui = do
 			Wormhole.sendFile sendf observer wormholeparams
 				`concurrently`
 			Wormhole.receiveFile recvf producer wormholeparams
-		liftIO $ nukeFile sendf
+		liftIO $ removeWhenExistsWith R.removeLink (toRawFilePath sendf)
 		if sendres /= True
 			then return SendFailed
 			else if recvres /= True
