@@ -30,8 +30,7 @@ optParser desc = RmUrlOptions
 
 seek :: RmUrlOptions -> CommandSeek
 seek o = case batchOption o of
-	Batch fmt -> batchInput fmt batchParser
-		(batchCommandAction . start)
+	Batch fmt -> batchInput fmt batchParser (batchCommandAction . start)
 	NoBatch -> withPairs (commandAction . start) (rmThese o)
 
 -- Split on the last space, since a FilePath can contain whitespace,
@@ -42,12 +41,14 @@ batchParser s = case separate (== ' ') (reverse s) of
 		| null ru || null rf -> return $ Left "Expected: \"file url\""
 		| otherwise -> do
 			let f = reverse rf
-			f' <- liftIO $ relPathCwdToFile f
+			f' <- liftIO $ fromRawFilePath
+				<$> relPathCwdToFile (toRawFilePath f)
 			return $ Right (f', reverse ru)
 
-start :: (FilePath, URLString) -> CommandStart
-start (file, url) = flip whenAnnexed file' $ \_ key ->
-	starting "rmurl" (mkActionItem (key, AssociatedFile (Just file'))) $
+start :: (SeekInput, (FilePath, URLString)) -> CommandStart
+start (si, (file, url)) = flip whenAnnexed file' $ \_ key -> do
+	let ai = mkActionItem (key, AssociatedFile (Just file'))
+	starting "rmurl" ai si $
 		next $ cleanup url key
   where
 	file' = toRawFilePath file
