@@ -67,7 +67,7 @@ import Annex.UpdateInstead
 import Annex.Export
 import Annex.TaggedPush
 import Annex.CurrentBranch
-import Annex.Import (canImportKeys)
+import Annex.Import
 import Annex.CheckIgnore
 import Types.FileMatcher
 import qualified Database.Export as Export
@@ -207,11 +207,11 @@ seek' o = do
 	let withbranch a = a =<< getCurrentBranch
 
 	remotes <- syncRemotes (syncWith o)
+	-- Remotes that are git repositories, not special remotes.
 	let gitremotes = filter (Remote.gitSyncableRemoteType . Remote.remotetype) remotes
-	dataremotes <- filter (\r -> Remote.uuid r /= NoUUID)
+	-- Remotes that contain annex object content.
+	contentremotes <- filter (\r -> Remote.uuid r /= NoUUID)
 		<$> filterM (not <$$> liftIO . getDynamicConfig . remoteAnnexIgnore . Remote.gitconfig) remotes
-	let (exportremotes, keyvalueremotes) = partition (exportTree . Remote.config) dataremotes
-	let importremotes = filter (importTree . Remote.config) dataremotes
 
 	if cleanupOption o
 		then do
@@ -231,17 +231,27 @@ seek' o = do
 			
 			content <- shouldSyncContent o
 
-			forM_ importremotes $
+			forM_ (filter isImport contentremotes) $
 				withbranch . importRemote content o mergeConfig
+			forM_ (filter isThirdPartyPopulated contentremotes) $
+				pullThirdPartyPopulated o
 			
 			when content $ do
 				-- Send content to any exports before other
 				-- repositories, in case that lets content
 				-- be dropped from other repositories.
 				exportedcontent <- withbranch $
-					seekExportContent (Just o) exportremotes
+					seekExportContent (Just o)
+						(filter isExport contentremotes)
+
+				-- Sync content with remotes, but not with
+				-- export or import remotes, which handle content
+				-- syncing as part of export and import.
 				syncedcontent <- withbranch $
-					seekSyncContent o keyvalueremotes
+					seekSyncContent o $ filter
+						(\r -> not (isExport r || isImport r))
+						contentremotes
+
 				-- Transferring content can take a while,
 				-- and other changes can be pushed to the
 				-- git-annex branch on the remotes in the
@@ -479,6 +489,33 @@ importRemote importcontent o mergeconfig remote currbranch
   where
 	wantpull = remoteAnnexPull (Remote.gitconfig remote)
 
+{- Handle a remote that is populated by a third party, by listing
+ - the contents of the remote, and then adding only the files on it that
+ - importKey identifies to a tree. The tree is only used to keep track
+ - of where keys are located on the remote, no remote tracking branch is
+ - updated, because the filenames are the names of annex object files,
+ - not suitable for a tracking branch. Does not transfer any content. -}
+pullThirdPartyPopulated :: SyncOptions -> Remote -> CommandSeek
+pullThirdPartyPopulated o remote
+	| not (pullOption o) || not wantpull = noop
+	| not (canImportKeys remote False) = noop
+	| otherwise = void $ includeCommandAction $ starting "list" ai si $
+		Command.Import.listContents' remote ImportTree (CheckGitIgnore False) go
+  where
+	go (Just importable) = importKeys remote ImportTree False True importable >>= \case
+		Just importablekeys -> do
+			(_imported, updatestate) <- recordImportTree remote ImportTree importablekeys
+			next $ do
+				updatestate
+				return True
+		Nothing -> next $ return False
+	go Nothing = next $ return True -- unchanged from before
+
+	ai = ActionItemOther (Just (Remote.name remote))
+	si = SeekInput []
+	
+	wantpull = remoteAnnexPull (Remote.gitconfig remote)
+
 {- The remote probably has both a master and a synced/master branch.
  - Which to merge from? Well, the master has whatever latest changes
  - were committed (or pushed changes, if this is a bare remote),
@@ -535,7 +572,7 @@ pushRemote o remote (Just branch, _) = do
 	postpushupdate repo = case Git.repoWorkTree repo of
 		Nothing -> return True
 		Just wt -> ifM needemulation
-			( gitAnnexChildProcess ["post-receive"]
+			( gitAnnexChildProcess "post-receive" []
 				(\cp -> cp { cwd = Just (fromRawFilePath wt) })
 				(\_ _ _ pid -> waitForProcess pid >>= return . \case
 					ExitSuccess -> True
@@ -778,6 +815,7 @@ syncFile ebloom rs af k = do
 
 	wantput r
 		| Remote.readonly r || remoteAnnexReadOnly (Remote.gitconfig r) = return False
+		| isThirdPartyPopulated r = return False
 		| otherwise = wantSend True (Just k) af (Remote.uuid r)
 	handleput lack = catMaybes <$> ifM (inAnnex k)
 		( forM lack $ \r ->
@@ -890,3 +928,12 @@ onlyAnnex o
 	| notOnlyAnnexOption o = pure False
 	| onlyAnnexOption o = pure True
 	| otherwise = getGitConfigVal annexSyncOnlyAnnex
+	
+isExport :: Remote -> Bool
+isExport = exportTree . Remote.config
+
+isImport :: Remote -> Bool
+isImport = importTree . Remote.config
+
+isThirdPartyPopulated :: Remote -> Bool
+isThirdPartyPopulated = Remote.thirdPartyPopulated . Remote.remotetype
