@@ -16,6 +16,7 @@ import qualified Git.LsFiles as LsFiles
 import qualified Git.Command as Git
 import qualified Git.Branch
 import qualified Command.Sync
+import qualified Utility.RawFilePath as R
 
 cmd :: Command
 cmd = notBareRepo $
@@ -41,8 +42,11 @@ seek ps = do
 	withStrings (commandAction . start) ps
 
 start :: FilePath -> CommandStart
-start p = starting "undo" (ActionItemOther (Just p)) $
+start p = starting "undo" ai si $
 	perform p
+  where
+	ai = ActionItemOther (Just p)
+	si = SeekInput [p]
 
 perform :: FilePath -> CommandPerform
 perform p = do
@@ -59,15 +63,15 @@ perform p = do
 	-- and then any adds. This order is necessary to handle eg, removing
 	-- a directory and replacing it with a file.
 	let (removals, adds) = partition (\di -> dstsha di `elem` nullShas) diff'
-	let mkrel di = liftIO $ relPathCwdToFile $ fromRawFilePath $
+	let mkrel di = liftIO $ relPathCwdToFile $
 		fromTopFilePath (file di) g
 
 	forM_ removals $ \di -> do
 		f <- mkrel di
-		liftIO $ nukeFile f
+		liftIO $ removeWhenExistsWith R.removeLink f
 
 	forM_ adds $ \di -> do
-		f <- mkrel di
+		f <- fromRawFilePath <$> mkrel di
 		inRepo $ Git.run [Param "checkout", Param "--", File f]
 
 	next $ liftIO cleanup
