@@ -16,6 +16,7 @@ import qualified Annex.Branch
 import qualified Database.Keys
 import Annex.Content
 import Annex.Init
+import Annex.CheckIgnore
 import Utility.FileMode
 import qualified Utility.RawFilePath as R
 
@@ -30,8 +31,8 @@ check = do
 	b <- current_branch
 	when (b == Annex.Branch.name) $ giveup $
 		"cannot uninit when the " ++ Git.fromRef b ++ " branch is checked out"
-	top <- fromRawFilePath <$> fromRepo Git.repoPath
-	currdir <- liftIO getCurrentDirectory
+	top <- fromRepo Git.repoPath
+	currdir <- liftIO R.getCurrentDirectory
 	whenM ((/=) <$> liftIO (absPath top) <*> liftIO (absPath currdir)) $
 		giveup "can only run uninit from the top of the git repository"
   where
@@ -42,7 +43,11 @@ check = do
 seek :: CmdParams -> CommandSeek
 seek ps = do
 	l <- workTreeItems ww ps
-	withFilesNotInGit (commandAction . whenAnnexed (startCheckIncomplete . fromRawFilePath)) l
+	withFilesNotInGit
+		(CheckGitIgnore False)
+		WarnUnmatchWorkTreeItems 
+		(\(_, f) -> commandAction $ whenAnnexed (startCheckIncomplete . fromRawFilePath) f)
+		l
 	Annex.changeState $ \s -> s { Annex.fast = True }
 	withFilesInGitAnnex ww Command.Unannex.seeker l
 	finish
@@ -68,7 +73,7 @@ finish = do
 		then liftIO $ removeDirectoryRecursive annexdir
 		else giveup $ unlines
 			[ "Not fully uninitialized"
-			, "Some annexed data is still left in " ++ annexobjectdir
+			, "Some annexed data is still left in " ++ fromRawFilePath annexobjectdir
 			, "This may include deleted files, or old versions of modified files."
 			, ""
 			, "If you don't care about preserving the data, just delete the"
@@ -103,7 +108,7 @@ prepareRemoveAnnexDir annexdir = do
 prepareRemoveAnnexDir' :: FilePath -> IO ()
 prepareRemoveAnnexDir' annexdir =
 	dirTreeRecursiveSkipping (const False) annexdir 
-		>>= mapM_ (void . tryIO . allowWrite)
+		>>= mapM_ (void . tryIO . allowWrite . toRawFilePath)
 
 {- Keys that were moved out of the annex have a hard link still in the
  - annex, with > 1 link count, and those can be removed.
