@@ -1,5 +1,3 @@
-{-# LANGUAGE PackageImports #-}
-
 module Common (module X) where
 
 import Control.Monad as X
@@ -15,15 +13,18 @@ import Data.Default as X
 import System.FilePath as X
 import System.IO as X hiding (FilePath)
 import System.Exit as X
-import System.PosixCompat.Files as X hiding (fileSize)
+import System.PosixCompat.Files as X hiding (fileSize, removeLink)
 
 import Utility.Misc as X
 import Utility.Exception as X
 import Utility.DebugLocks as X
 import Utility.SafeCommand as X
+import Utility.ShellEscape as X
 import Utility.Process as X
 import Utility.Path as X
+import Utility.Path.AbsRel as X
 import Utility.Directory as X
+import Utility.MoveFile as X
 import Utility.Monad as X
 import Utility.Data as X
 import Utility.Applicative as X
