@@ -43,6 +43,7 @@ import Git.FilePath
 import Git.Command
 import Git.Types
 import Git.Index
+import Config.Smudge
 import qualified Utility.RawFilePath as R
 
 import qualified Data.ByteString as S
@@ -237,15 +238,14 @@ reconcileStaged qh = do
 		liftIO $ writeFile indexcache $ showInodeCache cur
 	
 	diff =
-		-- Avoid using external diff command, which would be slow.
-		-- (The -G option may make it be used otherwise.)
-		[ Param "-c", Param "diff.external="
 		-- Avoid running smudge or clean filters, since we want the
 		-- raw output, and they would block trying to access the
 		-- locked database. The --raw normally avoids git diff
 		-- running them, but older versions of git need this.
-		, Param "-c", Param "filter.annex.smudge="
-		, Param "-c", Param "filter.annex.clean="
+		bypassSmudgeConfig ++
+		-- Avoid using external diff command, which would be slow.
+		-- (The -G option may make it be used otherwise.)
+		[ Param "-c", Param "diff.external="
 		, Param "diff"
 		, Param "--cached"
 		, Param "--raw"
