@@ -105,7 +105,7 @@ retrieveMissingObjects missing referencerepo r
 	| otherwise = withTmpDir "tmprepo" $ \tmpdir -> do
 		unlessM (boolSystem "git" [Param "init", File tmpdir]) $
 			error $ "failed to create temp repository in " ++ tmpdir
-		tmpr <- Config.read =<< Construct.fromAbsPath (toRawFilePath tmpdir)
+		tmpr <- Config.read =<< Construct.fromPath (toRawFilePath tmpdir)
 		rs <- Construct.fromRemotes r
 		stillmissing <- pullremotes tmpr rs fetchrefstags missing
 		if S.null (knownMissing stillmissing)
@@ -464,14 +464,19 @@ runRepair removablebranch forced g = do
 	putStrLn "Running git fsck ..."
 	fsckresult <- findBroken False g
 	if foundBroken fsckresult
-		then runRepair' removablebranch fsckresult forced Nothing g
+		then do
+			putStrLn "Fsck found problems, attempting repair."
+			runRepair' removablebranch fsckresult forced Nothing g
 		else do
+			putStrLn "Fsck found no problems. Checking for broken branches."
 			bad <- badBranches S.empty g
 			if null bad
 				then do
 					putStrLn "No problems found."
 					return (True, [])
-				else runRepair' removablebranch fsckresult forced Nothing g
+				else do
+					putStrLn "Found problems, attempting repair."
+					runRepair' removablebranch fsckresult forced Nothing g
 
 runRepairOf :: FsckResults -> (Ref -> Bool) -> Bool -> Maybe FilePath -> Repo -> IO (Bool, [Branch])
 runRepairOf fsckresult removablebranch forced referencerepo g = do
