@@ -13,7 +13,6 @@ import qualified Utility.Matcher
 import qualified Remote
 import Annex.Content
 import Annex.WorkTree
-import Annex.Action
 import Annex.UUID
 import Annex.Magic
 import Annex.Link
@@ -115,7 +114,7 @@ limitExclude glob = Right $ MatchFiles
 matchGlobFile :: String -> MatchInfo -> Annex Bool
 matchGlobFile glob = go
   where
-	cglob = compileGlob glob CaseSensative -- memoized
+	cglob = compileGlob glob CaseSensative (GlobFilePath True) -- memoized
 	go (MatchingFile fi) = pure $ matchGlob cglob (fromRawFilePath (matchFile fi))
 	go (MatchingInfo p) = pure $ matchGlob cglob (fromRawFilePath (providedFilePath p))
 	go (MatchingUserInfo p) = matchGlob cglob <$> getUserInfo (userProvidedFilePath p)
@@ -166,7 +165,7 @@ matchMagic _limitname querymagic selectprovidedinfo selectuserprovidedinfo (Just
 		, matchNeedsLocationLog = False
 		}
   where
- 	cglob = compileGlob glob CaseSensative -- memoized
+ 	cglob = compileGlob glob CaseSensative (GlobFilePath False) -- memoized
 	go (MatchingKey _ _) = pure False
 	go (MatchingFile fi) = case contentFile fi of
 		Just f -> catchBoolIO $
@@ -496,25 +495,6 @@ limitMetaData s = case parseMetaDataMatcher s of
 		. S.filter matching
 		. metaDataValues f <$> getCurrentMetaData k
 
-addTimeLimit :: Duration -> Annex ()
-addTimeLimit duration = do
-	start <- liftIO getPOSIXTime
-	let cutoff = start + durationToPOSIXTime duration
-	addLimit $ Right $ MatchFiles
-		{ matchAction = const $ const $ do
-			now <- liftIO getPOSIXTime
-			if now > cutoff
-				then do
-					warning $ "Time limit (" ++ fromDuration duration ++ ") reached!"
-					shutdown True
-					liftIO $ exitWith $ ExitFailure 101
-				else return True
-		, matchNeedsFileName = False
-		, matchNeedsFileContent = False
-		, matchNeedsKey = False
-		, matchNeedsLocationLog = False
-		}
-
 addAccessedWithin :: Duration -> Annex ()
 addAccessedWithin duration = do
 	now <- liftIO getPOSIXTime
@@ -535,9 +515,11 @@ addAccessedWithin duration = do
 	secs = fromIntegral (durationSeconds duration)
 
 lookupFileKey :: FileInfo -> Annex (Maybe Key)
-lookupFileKey fi = case contentFile fi of
-	Just f -> lookupKey f
-	Nothing -> return Nothing
+lookupFileKey fi = case matchKey fi of
+	Just k -> return (Just k)
+	Nothing -> case contentFile fi of
+		Just f -> lookupKey f
+		Nothing -> return Nothing
 
 checkKey :: (Key -> Annex Bool) -> MatchInfo -> Annex Bool
 checkKey a (MatchingFile fi) = lookupFileKey fi >>= maybe (return False) a
