@@ -1,6 +1,6 @@
-{- git-annex export log
+{- git-annex export log (also used to log imports)
  -
- - Copyright 2017-2019 Joey Hess <id@joeyh.name>
+ - Copyright 2017-2020 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU AGPL version 3 or higher.
  -}
@@ -15,8 +15,9 @@ module Logs.Export (
 	getExport,
 	exportedTreeishes,
 	incompleteExportedTreeishes,
-	recordExport,
 	recordExportBeginning,
+	recordExportUnderway,
+	recordExport,
 	logExportExcluded,
 	getExportExcluded,
 ) where
@@ -64,7 +65,6 @@ exportedTreeishes = nub . map exportedTreeish
 incompleteExportedTreeishes :: [Exported] -> [Git.Ref]
 incompleteExportedTreeishes = concatMap incompleteExportedTreeish
 
-
 data ExportParticipants = ExportParticipants
 	{ exportFrom :: UUID
 	, exportTo :: UUID
@@ -86,7 +86,36 @@ getExport remoteuuid = nub . mapMaybe get . M.toList . simpleMap
 		| exportTo ep == remoteuuid = Just exported
 		| otherwise = Nothing
 
--- | Record a change in what's exported to a special remote.
+-- | Record the beginning of an export, to allow cleaning up from
+-- interrupted exports.
+--
+-- This is called before any changes are made to the remote.
+recordExportBeginning :: UUID -> Git.Ref -> Annex ()
+recordExportBeginning remoteuuid newtree = do
+	c <- currentVectorClock
+	u <- getUUID
+	let ep = ExportParticipants { exportFrom = u, exportTo = remoteuuid }
+	old <- fromMaybe (Exported emptyTree [])
+		. M.lookup ep . simpleMap 
+		. parseExportLog
+		<$> Annex.Branch.get exportLog
+	let new = old { incompleteExportedTreeish = nub (newtree:incompleteExportedTreeish old) }
+	Annex.Branch.change exportLog $
+		buildExportLog 
+			. changeMapLog c ep new
+			. parseExportLog
+	recordExportTreeish newtree
+
+-- Grade a tree ref into the git-annex branch. This is done
+-- to ensure that it's available later, when getting exported files
+-- from the remote. Since that could happen in another clone of the
+-- repository, the tree has to be kept available, even if it
+-- doesn't end up being merged into the master branch.
+recordExportTreeish :: Git.Ref -> Annex ()
+recordExportTreeish t = 
+	Annex.Branch.rememberTreeish t (asTopFilePath "export.tree")
+
+-- | Record that an export to a special remote is under way.
 --
 -- This is called before an export begins uploading new files to the
 -- remote, but after it's cleaned up any files that need to be deleted
@@ -96,12 +125,9 @@ getExport remoteuuid = nub . mapMaybe get . M.toList . simpleMap
 -- newTreeish. This way, when multiple repositories are exporting to
 -- the same special remote, there's no conflict as long as they move
 -- forward in lock-step.
---
--- Also, the newTreeish is grafted into the git-annex branch. This is done
--- to ensure that it's available later.
-recordExport :: UUID -> ExportChange -> Annex ()
-recordExport remoteuuid ec = do
-	c <- liftIO currentVectorClock
+recordExportUnderway :: UUID -> ExportChange -> Annex ()
+recordExportUnderway remoteuuid ec = do
+	c <- currentVectorClock
 	u <- getUUID
 	let ep = ExportParticipants { exportFrom = u, exportTo = remoteuuid }
 	let exported = Exported (newTreeish ec) []
@@ -115,25 +141,16 @@ recordExport remoteuuid ec = do
 		| u == exportFrom ep || remoteuuid /= exportTo ep || t `notElem` oldTreeish ec = le
 		| otherwise = LogEntry c (exported { exportedTreeish = newTreeish ec })
 
--- | Record the beginning of an export, to allow cleaning up from
--- interrupted exports.
+-- Record information about the export to the git-annex branch.
 --
--- This is called before any changes are made to the remote.
-recordExportBeginning :: UUID -> Git.Ref -> Annex ()
-recordExportBeginning remoteuuid newtree = do
-	c <- liftIO currentVectorClock
-	u <- getUUID
-	let ep = ExportParticipants { exportFrom = u, exportTo = remoteuuid }
-	old <- fromMaybe (Exported emptyTree [])
-		. M.lookup ep . simpleMap 
-		. parseExportLog
-		<$> Annex.Branch.get exportLog
-	let new = old { incompleteExportedTreeish = nub (newtree:incompleteExportedTreeish old) }
-	Annex.Branch.change exportLog $
-		buildExportLog 
-			. changeMapLog c ep new
-			. parseExportLog
-	Annex.Branch.rememberTreeish newtree (asTopFilePath "export.tree")
+-- This is equivilant to recordExportBeginning followed by
+-- recordExportUnderway, but without the ability to clean up from
+-- interrupted exports.
+recordExport :: UUID -> Git.Ref -> ExportChange -> Annex ()
+recordExport remoteuuid tree ec = do
+	when (oldTreeish ec /= [tree]) $
+		recordExportTreeish tree
+	recordExportUnderway remoteuuid ec
 
 parseExportLog :: L.ByteString -> MapLog ExportParticipants Exported
 parseExportLog = parseMapLog exportParticipantsParser exportedParser
@@ -180,10 +197,12 @@ logExportExcluded u a = do
 getExportExcluded :: UUID -> Annex [Git.Tree.TreeItem]
 getExportExcluded u = do
 	logf <- fromRepo $ gitAnnexExportExcludeLog u
-	liftIO $ catchDefaultIO [] $ parser
+	liftIO $ catchDefaultIO [] $ exportExcludedParser
 		<$> L.readFile (fromRawFilePath logf)
   where
-	parser = map Git.Tree.lsTreeItemToTreeItem
-		. rights
-		. map Git.LsTree.parseLsTree
-		. L.split (fromIntegral $ ord '\n')
+
+exportExcludedParser :: L.ByteString -> [Git.Tree.TreeItem]
+exportExcludedParser = map Git.Tree.lsTreeItemToTreeItem
+	. rights
+	. map Git.LsTree.parseLsTree
+	. L.split (fromIntegral $ ord '\n')
