@@ -1,6 +1,6 @@
 {- git-annex trust log
  -
- - Copyright 2010-2012 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2020 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU AGPL version 3 or higher.
  -}
@@ -64,20 +64,15 @@ trustMap = maybe trustMapLoad return =<< Annex.getState Annex.trustmap
 {- Loads the map, updating the cache, -}
 trustMapLoad :: Annex TrustMap
 trustMapLoad = do
-	overrides <- Annex.getState Annex.forcetrust
+	forceoverrides <- Annex.getState Annex.forcetrust
 	l <- remoteList
-	-- Exports are not trusted, since they are not key/value stores.
-	-- This does not apply to appendonly exports, which are key/value
-	-- stores.
-	let untrustworthy r = pure (not (Types.Remote.appendonly r)) 
-		<&&> Types.Remote.isExportSupported r 
-	exports <- filterM untrustworthy l
-	let exportoverrides = M.fromList $
-		map (\r -> (Types.Remote.uuid r, UnTrusted)) exports
+	let untrustoverrides = M.fromList $
+		map (\r -> (Types.Remote.uuid r, UnTrusted))
+		(filter Types.Remote.untrustworthy l)
 	logged <- trustMapRaw
 	let configured = M.fromList $ mapMaybe configuredtrust l
-	let m = M.unionWith min exportoverrides $
-		M.union overrides $
+	let m = M.unionWith min untrustoverrides $
+		M.union forceoverrides $
 		M.union configured logged
 	Annex.changeState $ \s -> s { Annex.trustmap = Just m }
 	return m
