@@ -1,6 +1,6 @@
 {- git-annex output messages, including concurrent output to display regions
  -
- - Copyright 2010-2018 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2020 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU AGPL version 3 or higher.
  -}
@@ -29,25 +29,32 @@ outputMessage' jsonoutputter jsonbuilder msg = withMessageState $ \s -> case out
 		| otherwise -> liftIO $ flushed $ S.putStr msg
 	JSONOutput _ -> void $ jsonoutputter jsonbuilder s
 	QuietOutput -> q
+	SerializedOutput h _ -> do
+		liftIO $ outputSerialized h $ OutputMessage msg
+		void $ jsonoutputter jsonbuilder s
 
 -- Buffer changes to JSON until end is reached and then emit it.
 bufferJSON :: JSONBuilder -> MessageState -> Annex Bool
 bufferJSON jsonbuilder s = case outputType s of
-	JSONOutput jsonoptions
-		| endjson -> do
+	JSONOutput _ -> go (flushed . JSON.emit)
+	SerializedOutput h _ -> go (outputSerialized h . JSONObject . JSON.encode)
+	_ -> return False
+  where
+	go emitter
+		| endjson = do
 			Annex.changeState $ \st -> 
 				st { Annex.output = s { jsonBuffer = Nothing } }
-			maybe noop (liftIO . flushed . JSON.emit . JSON.finalize jsonoptions) json
+			maybe noop (liftIO . emitter . JSON.finalize) json
 			return True
-		| otherwise -> do
+		| otherwise = do
 			Annex.changeState $ \st ->
 			        st { Annex.output = s { jsonBuffer = json } }
 			return True
-	_ -> return False
-  where
+	
 	(json, endjson) = case jsonbuilder i of
 		Nothing -> (jsonBuffer s, False)
 		(Just (j, e)) -> (Just j, e)
+	
 	i = case jsonBuffer s of
 		Nothing -> Nothing
 		Just b -> Just (b, False)
@@ -55,11 +62,14 @@ bufferJSON jsonbuilder s = case outputType s of
 -- Immediately output JSON.
 outputJSON :: JSONBuilder -> MessageState -> Annex Bool
 outputJSON jsonbuilder s = case outputType s of
-	JSONOutput _ -> do
-		maybe noop (liftIO . flushed . JSON.emit)
+	JSONOutput _ -> go (flushed . JSON.emit)
+	SerializedOutput h _ -> go (outputSerialized h . JSONObject . JSON.encode)
+	_ -> return False
+  where
+	go emitter = do
+		maybe noop (liftIO . emitter)
 			(fst <$> jsonbuilder Nothing)
 		return True
-	_ -> return False
 
 outputError :: String -> Annex ()
 outputError msg = withMessageState $ \s -> case (outputType s, jsonBuffer s) of
@@ -67,6 +77,8 @@ outputError msg = withMessageState $ \s -> case (outputType s, jsonBuffer s) of
 		let jb' = Just (JSON.addErrorMessage (lines msg) jb)
 		in Annex.changeState $ \st ->
 			st { Annex.output = s { jsonBuffer = jb' } }
+	(SerializedOutput h _, _) -> 
+		liftIO $ outputSerialized h $ OutputError msg
 	_
 		| concurrentOutputEnabled s -> concurrentMessage s True msg go
 		| otherwise -> go
@@ -81,3 +93,12 @@ q = noop
 
 flushed :: IO () -> IO ()
 flushed a = a >> hFlush stdout
+
+outputSerialized :: (SerializedOutput -> IO ()) -> SerializedOutput -> IO ()
+outputSerialized = id
+
+-- | Wait for the specified response.
+waitOutputSerializedResponse :: (IO (Maybe SerializedOutputResponse)) -> SerializedOutputResponse -> IO ()
+waitOutputSerializedResponse getr r = tryIO getr >>= \case
+	Right (Just r') | r' == r -> return ()
+	v -> error $ "serialized output protocol error; expected " ++ show r ++ " got " ++ show v
