@@ -53,6 +53,7 @@ remote = specialRemoteType $ RemoteType
 	, setup = externalSetup
 	, exportSupported = checkExportSupported
 	, importSupported = importUnsupported
+	, thirdPartyPopulated = False
 	}
 
 externaltypeField :: RemoteConfigField
@@ -80,8 +81,9 @@ gen r u rc gc rs
 			exportUnsupported
 	| otherwise = do
 		c <- parsedRemoteConfig remote rc
-		external <- newExternal externaltype (Just u) c (Just gc) (Just rs)
-		Annex.addCleanup (RemoteCleanup u) $ stopExternal external
+		external <- newExternal externaltype (Just u) c (Just gc)
+			(Git.remoteName r) (Just rs)
+		Annex.addCleanupAction (RemoteCleanup u) $ stopExternal external
 		cst <- getCost external r gc
 		avail <- getAvailability external r gc
 		exportsupported <- if exportTree c
@@ -92,6 +94,7 @@ gen r u rc gc rs
 				{ storeExport = storeExportM external
 				, retrieveExport = retrieveExportM external
 				, removeExport = removeExportM external
+				, versionedExport = False
 				, checkPresentExport = checkPresentExportM external
 				, removeExportDirectory = Just $ removeExportDirectoryM external
 				, renameExport = renameExportM external
@@ -142,6 +145,7 @@ gen r u rc gc rs
 			, gitconfig = gc
 			, readonly = False
 			, appendonly = False
+			, untrustworthy = False
 			, availability = avail
 			, remotetype = remote 
 				{ exportSupported = cheapexportsupported }
@@ -181,7 +185,7 @@ externalSetup _ mu _ c gc = do
 			return c'
 		else do
 			pc' <- either giveup return $ parseRemoteConfig c' lenientRemoteConfigParser
-			external <- newExternal externaltype (Just u) pc' (Just gc) Nothing
+			external <- newExternal externaltype (Just u) pc' (Just gc) Nothing Nothing
 			-- Now that we have an external, ask it to LISTCONFIGS, 
 			-- and re-parse the RemoteConfig strictly, so we can
 			-- error out if the user provided an unexpected config.
@@ -209,7 +213,7 @@ checkExportSupported c gc = do
 	if externaltype == "readonly"
 		then return False
 		else checkExportSupported' 
-			=<< newExternal externaltype Nothing c (Just gc) Nothing
+			=<< newExternal externaltype Nothing c (Just gc) Nothing Nothing
 
 checkExportSupported' :: External -> Annex Bool
 checkExportSupported' external = go `catchNonAsync` (const (return False))
@@ -455,6 +459,10 @@ handleRequest' st external req mp responsehandler
 		Nothing -> senderror "cannot send GETUUID here"
 	handleRemoteRequest GETGITDIR = 
 		send . VALUE . fromRawFilePath =<< fromRepo Git.localGitDir
+	handleRemoteRequest GETGITREMOTENAME =
+		case externalRemoteName external of
+			Just n -> send $ VALUE n
+			Nothing -> senderror "git remote name not known"
 	handleRemoteRequest (SETWANTED expr) = case externalUUID external of
 		Just u -> preferredContentSet u expr
 		Nothing -> senderror "cannot send SETWANTED here"
@@ -619,7 +627,8 @@ startExternal external =
 				`onException` store UncheckedExternalAsync
 			if asyncExtensionEnabled extensions
 				then do
-					relay <- liftIO $ runRelayToExternalAsync external st
+					annexrunner <- Annex.makeRunner
+					relay <- liftIO $ runRelayToExternalAsync external st annexrunner
 					st' <- liftIO $ asyncRelayExternalState relay
 					store (ExternalAsync relay)
 					return st'
@@ -892,7 +901,7 @@ remoteConfigParser c
 			(Nothing, _) -> return lenientRemoteConfigParser
 			(_, Just True) -> return lenientRemoteConfigParser
 			(Just externaltype, _) -> do
-				external <- newExternal externaltype Nothing pc Nothing Nothing
+				external <- newExternal externaltype Nothing pc Nothing Nothing Nothing
 				strictRemoteConfigParser external
   where
 	isproposed (Accepted _) = False
