@@ -67,7 +67,7 @@ remote :: RemoteType
 remote = specialRemoteType $ RemoteType
 	{ typename = "gcrypt"
 	-- Remote.Git takes care of enumerating gcrypt remotes too,
-	-- and will call our gen on them.
+	-- and will call our chainGen on them.
 	, enumerate = const (return [])
 	, generate = gen
 	, configParser = mkRemoteConfigParser $
@@ -78,6 +78,7 @@ remote = specialRemoteType $ RemoteType
 	, setup = gCryptSetup
 	, exportSupported = exportUnsupported
 	, importSupported = importUnsupported
+	, thirdPartyPopulated = False
 	}
 
 gitRepoField :: RemoteConfigField
@@ -152,6 +153,7 @@ gen' r u c gc rs = do
 		, gitconfig = gc
 		, readonly = Git.repoIsHttp r
 		, appendonly = False
+		, untrustworthy = False
 		, availability = availabilityCalc r
 		, remotetype = remote
 		, mkUnavailable = return Nothing
