@@ -74,6 +74,7 @@ remote = specialRemoteType $ RemoteType
 	, setup = mySetup
 	, exportSupported = exportUnsupported
 	, importSupported = importUnsupported
+	, thirdPartyPopulated = False
 	}
 
 urlField :: RemoteConfigField
@@ -132,6 +133,7 @@ gen r u rc gc rs = do
 		, readonly = False
 		-- content cannot be removed from a git-lfs repo
 		, appendonly = True
+		, untrustworthy = False
 		, mkUnavailable = return Nothing
 		, getInfo = gitRepoInfo (this c cst h)
 		, claimUrl = Nothing
@@ -253,14 +255,16 @@ discoverLFSEndpoint tro h
 			return Nothing
 		Just (Right hostuser) -> do
 			let port = Git.Url.port r
+			let p = fromMaybe (error "unknown path")
+				(Git.Url.path r)
 			-- Remove leading /~/ from path. That is added when
 			-- converting a scp-style repository location with
 			-- a relative path into an url, and is legal
 			-- according to git-clone(1), but github does not
 			-- support it.
-			let remotepath = if "/~/" `isPrefixOf` Git.Url.path r
-				then drop 3 (Git.Url.path r)
-				else Git.Url.path r
+			let remotepath = if "/~/" `isPrefixOf` p
+				then drop 3 p
+				else p
 			let ps = LFS.sshDiscoverEndpointCommand remotepath tro
 			-- Note that no shellEscape is done here, because
 			-- at least github's git-lfs implementation does
