@@ -118,6 +118,7 @@ remote = specialRemoteType $ RemoteType
 	, setup = s3Setup
 	, exportSupported = exportIsSupported
 	, importSupported = importIsSupported
+	, thirdPartyPopulated = False
 	}
 
 bucketField :: RemoteConfigField
@@ -209,6 +210,7 @@ gen r u rc gc rs = do
 				{ storeExport = storeExportS3 hdl this rs info magic
 				, retrieveExport = retrieveExportS3 hdl this info
 				, removeExport = removeExportS3 hdl this rs info
+				, versionedExport = versioning info
 				, checkPresentExport = checkPresentExportS3 hdl this info
 				-- S3 does not have directories.
 				, removeExportDirectory = Nothing
@@ -231,7 +233,8 @@ gen r u rc gc rs = do
 			, gitconfig = gc
 			, localpath = Nothing
 			, readonly = False
-			, appendonly = versioning info
+			, appendonly = False
+			, untrustworthy = False
 			, availability = GloballyAvailable
 			, remotetype = remote
 			, mkUnavailable = gen r u (M.insert hostField (Proposed "!dne!") rc) gc rs
@@ -552,12 +555,11 @@ renameExportS3 hv r rs info k src dest = Just <$> go
 listImportableContentsS3 :: S3HandleVar -> Remote -> S3Info -> Annex (Maybe (ImportableContents (ContentIdentifier, ByteSize)))
 listImportableContentsS3 hv r info =
 	withS3Handle hv $ \case
-		Nothing -> do
-			warning $ needS3Creds (uuid r)
-			return Nothing
-		Just h -> catchMaybeIO $ liftIO $ runResourceT $
-			extractFromResourceT =<< startlist h
+		Nothing -> giveup $ needS3Creds (uuid r)
+		Just h -> Just <$> go h
   where
+	go h = liftIO $ runResourceT $ extractFromResourceT =<< startlist h
+
 	startlist h
 		| versioning info = do
 			rsp <- sendS3Handle h $ 
@@ -656,7 +658,10 @@ retrieveExportWithContentIdentifierS3 hv r rs info loc cid dest mkkey p = withS3
 				S3.getObject (bucket info) o
 		k <- mkkey
 		case extractContentIdentifier cid o of
-			Right vid -> setS3VersionID info rs k vid
+			Right vid -> do
+				vids <- getS3VersionID rs k
+				unless (vid `elem` map Just vids) $
+					setS3VersionID info rs k vid
 			Left _ -> noop
 		return k
 	Nothing -> giveup $ needS3Creds (uuid r)
@@ -1132,7 +1137,7 @@ getPublicUrlMaker info = case publicurl info of
 -- version id involves a request for an object, so this keeps track of what
 -- the object is.
 data S3VersionID = S3VersionID S3.Object T.Text
-	deriving (Show)
+	deriving (Show, Eq)
 
 -- smart constructor
 mkS3VersionID :: S3.Object -> Maybe T.Text -> Maybe S3VersionID
