@@ -1,6 +1,6 @@
 {- git-annex test suite
  -
- - Copyright 2010-2020 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2021 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU AGPL version 3 or higher.
  -}
@@ -224,17 +224,30 @@ properties = localOption (QuickCheckTests 1000) $ testGroup "QuickCheck" $
 
 testRemotes :: TestTree
 testRemotes = testGroup "Remote Tests"
-	[ testRemote "directory"
-		[ "directory=remotedir"
-		, "encryption=none"
-		]
-		(createDirectory "remotedir")
+	[ testGitRemote
+	, testDirectoryRemote
 	]
 
-testRemote :: String -> [String] -> IO () -> TestTree
-testRemote remotetype config preinitremote = 
+testGitRemote :: TestTree
+testGitRemote = testRemote False "git" $ \remotename -> do
+	git "clone" [".", "remotedir"] "git clone"
+	git "remote" ["add", remotename, "remotedir"] "git remote add"
+
+testDirectoryRemote :: TestTree
+testDirectoryRemote = testRemote True "directory" $ \remotename -> do
+	createDirectory "remotedir"
+	git_annex "initremote"
+		[ remotename
+		, "type=directory"
+		, "--quiet"
+		, "directory=remotedir"
+		, "encryption=none"
+		] "init"
+			
+testRemote :: Bool -> String -> (String -> IO ()) -> TestTree
+testRemote testvariants remotetype setupremote = 
 	withResource newEmptyTMVarIO (const noop) $ \getv -> 
-		testGroup ("remote type " ++ remotetype) $ concat
+		testGroup ("testremote type " ++ remotetype) $ concat
 			[ [testCase "init" (prep getv)]
 			, go getv
 			]
@@ -248,13 +261,7 @@ testRemote remotetype config preinitremote =
 		setmainrepodir d
 		innewrepo $ do
 			git_annex "init" [reponame, "--quiet"] "init"
-			preinitremote
-			git_annex "initremote"
-				([ remotename
-				, "type=" ++ remotetype
-				, "--quiet"
-				] ++ config)
-				"init"
+			setupremote remotename
 			r <- annexeval $ either error return 
 				=<< Remote.byName' remotename
 			cache <- Command.TestRemote.newRemoteVariantCache
@@ -268,7 +275,9 @@ testRemote remotetype config preinitremote =
 	go getv = Command.TestRemote.mkTestTrees runannex mkrs mkunavailr mkexportr mkks
 	  where
 		runannex = inmainrepo . annexeval
-		mkrs = Command.TestRemote.remoteVariants cache mkr basesz False
+		mkrs = if testvariants
+			then Command.TestRemote.remoteVariants cache mkr basesz False
+			else [fmap (fmap Just) mkr]
 		mkr = descas (remotetype ++ " remote") (fst <$> v)
 		mkunavailr = fst . snd <$> v
 		mkexportr = fst . snd . snd <$> v
@@ -838,9 +847,9 @@ test_fix = intmpclonerepo $ unlessM (hasUnlockedFiles <$> getTestMode) $ do
 
 test_trust :: Assertion
 test_trust = intmpclonerepo $ do
-	git_annex "trust" [repo] "trust"
+	git_annex "trust" ["--force", repo] "trust"
 	trustcheck Logs.Trust.Trusted "trusted 1"
-	git_annex "trust" [repo] "trust of trusted"
+	git_annex "trust" ["--force", repo] "trust of trusted"
 	trustcheck Logs.Trust.Trusted "trusted 2"
 	git_annex "untrust" [repo] "untrust"
 	trustcheck Logs.Trust.UnTrusted "untrusted 1"
@@ -892,7 +901,7 @@ test_fsck_localuntrusted = intmpclonerepo $ do
 	git_annex "untrust" ["origin"] "untrust of origin repo"
 	git_annex "untrust" ["."] "untrust of current repo"
 	fsck_should_fail "content only available in untrusted (current) repository"
-	git_annex "trust" ["."] "trust of current repo"
+	git_annex "trust" ["--force", "."] "trust of current repo"
 	git_annex "fsck" [annexedfile] "fsck on file present in trusted repo"
 
 test_fsck_remoteuntrusted :: Assertion
