@@ -40,34 +40,51 @@ import qualified Annex.Path
 import qualified Annex.Action
 import qualified Annex.AdjustedBranch
 import qualified Utility.Process
+import qualified Utility.Process.Transcript
 import qualified Utility.Env
 import qualified Utility.Env.Set
 import qualified Utility.Exception
 import qualified Utility.ThreadScheduler
 import qualified Utility.Tmp.Dir
 import qualified Utility.Metered
-import qualified Utility.SafeCommand
 import qualified Command.Uninit
 
+-- Run a process. The output and stderr is captured, and is only
+-- displayed if the process does not return the expected value.
+testProcess :: String -> [String] -> (Bool -> Bool) -> String -> Assertion
+testProcess command params expectedret faildesc = do
+	(transcript, ret) <- Utility.Process.Transcript.processTranscript command params Nothing
+	(expectedret ret) @? (faildesc ++ " failed (transcript follows)\n" ++ transcript)
+
+-- Run git. (Do not use to run git-annex as the one being tested
+-- may not be in path.)
+git :: String -> [String] -> String -> Assertion
+git command params = testProcess "git" (command:params) (== True)
+
+-- For when git is expected to fail.
+git_shouldfail :: String -> [String] -> String -> Assertion
+git_shouldfail command params = testProcess "git" (command:params) (== False)
+
 -- Run git-annex.
-git_annex :: String -> [String] -> IO Bool
-git_annex command params = do
-	pp <- Annex.Path.programPath
-	Utility.SafeCommand.boolSystem pp $
-		map Utility.SafeCommand.Param (command:params)
+git_annex :: String -> [String] -> String -> Assertion
+git_annex = git_annex' (== True)
 
 -- For when git-annex is expected to fail.
--- Run with -q to squelch error.
-git_annex_shouldfail :: String -> [String] -> IO Bool
-git_annex_shouldfail command params = not <$> git_annex command ("-q":params)
+git_annex_shouldfail :: String -> [String] -> String -> Assertion
+git_annex_shouldfail = git_annex' (== False)
 
-{- Runs git-annex and returns its output. -}
+git_annex' :: (Bool -> Bool) -> String -> [String] -> String -> Assertion
+git_annex' expectedret command params faildesc = do
+	pp <- Annex.Path.programPath
+	testProcess pp (command:params) expectedret faildesc
+
+{- Runs git-annex and returns its standard output. -}
 git_annex_output :: String -> [String] -> IO String
 git_annex_output command params = do
 	pp <- Annex.Path.programPath
 	Utility.Process.readProcess pp (command:params)
 
-git_annex_expectoutput :: String -> [String] -> [String] -> IO ()
+git_annex_expectoutput :: String -> [String] -> [String] -> Assertion
 git_annex_expectoutput command params expected = do
 	got <- lines <$> git_annex_output command params
 	got == expected @? ("unexpected value running " ++ command ++ " " ++ show params ++ " -- got: " ++ show got ++ " expected: " ++ show expected)
@@ -93,9 +110,10 @@ with_ssh_origin :: (Assertion -> Assertion) -> (Assertion -> Assertion)
 with_ssh_origin cloner a = cloner $ do
 	let k = Git.Types.ConfigKey (encodeBS' config)
 	let v = Git.Types.ConfigValue (toRawFilePath "/dev/null")
-	origindir <- absPath . Git.Types.fromConfigValue =<< annexeval (Config.getConfig k v)
-	let originurl = "localhost:" ++ origindir
-	boolSystem "git" [Param "config", Param config, Param originurl] @? "git config failed"
+	origindir <- absPath . Git.Types.fromConfigValue
+		=<< annexeval (Config.getConfig k v)
+	let originurl = "localhost:" ++ fromRawFilePath origindir
+	git "config" [config, originurl] "git config failed"
 	a
   where
 	config = "remote.origin.url"
@@ -105,7 +123,7 @@ intmpclonerepo a = withtmpclonerepo $ \r -> indir r a
 
 checkRepo :: Types.Annex a -> FilePath -> IO a
 checkRepo getval d = do
-	s <- Annex.new =<< Git.Construct.fromPath d
+	s <- Annex.new =<< Git.Construct.fromPath (toRawFilePath d)
 	Annex.eval s $
 		getval `finally` Annex.Action.stopCoProcesses
 
@@ -134,7 +152,7 @@ withtmpclonerepo' cfg a = do
 			throwM e
 
 disconnectOrigin :: Assertion
-disconnectOrigin = boolSystem "git" [Param "remote", Param "rm", Param "origin"] @? "remote rm"
+disconnectOrigin = git "remote" ["rm", "origin"] "remote rm"
 
 withgitrepo :: (FilePath -> Assertion) -> Assertion
 withgitrepo a = do
@@ -162,7 +180,7 @@ setuprepo :: FilePath -> IO FilePath
 setuprepo dir = do
 	cleanup dir
 	ensuretmpdir
-	boolSystem "git" [Param "init", Param "-q", File dir] @? "git init failed"
+	git "init" ["-q", dir] "git init"
 	configrepo dir
 	return dir
 
@@ -183,18 +201,22 @@ clonerepo old new cfg = do
 	cleanup new
 	ensuretmpdir
 	let cloneparams = catMaybes
-		[ Just $ Param "clone"
-		, Just $ Param "-q"
-		, if bareClone cfg then Just (Param "--bare") else Nothing
-		, if sharedClone cfg then Just (Param "--shared") else Nothing
-		, Just $ File old
-		, Just $ File new
+		[ Just "-q"
+		, if bareClone cfg then Just "--bare" else Nothing
+		, if sharedClone cfg then Just "--shared" else Nothing
+		, Just old
+		, Just new
 		]
-	boolSystem "git" cloneparams @? "git clone failed"
+	git "clone" cloneparams "git clone"
 	configrepo new
 	indir new $ do
 		ver <- annexVersion <$> getTestMode
-		git_annex "init" ["-q", new, "--version", show (Types.RepoVersion.fromRepoVersion ver)] @? "git annex init failed"
+		git_annex "init" 
+			[ "-q"
+			, new, "--version"
+			, show (Types.RepoVersion.fromRepoVersion ver)
+			]
+			"git annex init"
 	unless (bareClone cfg) $
 		indir new $
 			setupTestMode
@@ -203,16 +225,16 @@ clonerepo old new cfg = do
 configrepo :: FilePath -> IO ()
 configrepo dir = indir dir $ do
 	-- ensure git is set up to let commits happen
-	boolSystem "git" [Param "config", Param "user.name", Param "Test User"] @? "git config failed"
-	boolSystem "git" [Param "config", Param "user.email", Param "test@example.com"] @? "git config failed"
+	git "config" ["user.name", "Test User"]
+		"git config"
+	git "config" ["user.email", "test@example.com"]
+		"git config"
 	-- avoid signed commits by test suite
-	boolSystem "git" [Param "config", Param "commit.gpgsign", Param "false"] @? "git config failed"
+	git "config" ["commit.gpgsign", "false"]
+		"git config"
 	-- tell git-annex to not annex the ingitfile
-	boolSystem "git"
-		[ Param "config"
-		, Param "annex.largefiles"
-		, Param ("exclude=" ++ ingitfile)
-		] @? "git config annex.largefiles failed"
+	git "config" ["annex.largefiles", "exclude=" ++ ingitfile]
+		"git config annex.largefiles"
 
 ensuretmpdir :: IO ()
 ensuretmpdir = do
@@ -223,7 +245,7 @@ ensuretmpdir = do
 {- Prevent global git configs from affecting the test suite. -}
 isolateGitConfig :: IO a -> IO a
 isolateGitConfig a = Utility.Tmp.Dir.withTmpDir "testhome" $ \tmphome -> do
-	tmphomeabs <- absPath tmphome
+	tmphomeabs <- fromRawFilePath <$> absPath (toRawFilePath tmphome)
 	Utility.Env.Set.setEnv "HOME" tmphomeabs True
 	Utility.Env.Set.setEnv "XDG_CONFIG_HOME" tmphomeabs True
 	Utility.Env.Set.setEnv "GIT_CONFIG_NOSYSTEM" "1" True
@@ -245,15 +267,13 @@ cleanup dir = whenM (doesDirectoryExist dir) $ do
 
 finalCleanup :: IO ()
 finalCleanup = whenM (doesDirectoryExist tmpdir) $ do
-	Annex.Action.reapZombies
 	Command.Uninit.prepareRemoveAnnexDir' tmpdir
 	catchIO (removeDirectoryForCleanup tmpdir) $ \e -> do
 		print e
 		putStrLn "sleeping 10 seconds and will retry directory cleanup"
 		Utility.ThreadScheduler.threadDelaySeconds $
 			Utility.ThreadScheduler.Seconds 10
-		whenM (doesDirectoryExist tmpdir) $ do
-			Annex.Action.reapZombies
+		whenM (doesDirectoryExist tmpdir) $
 			removeDirectoryForCleanup tmpdir
 
 checklink :: FilePath -> Assertion
@@ -395,10 +415,10 @@ annexed_notpresent_imported f = ifM (annexeval Config.crippledFileSystem)
 unannexed :: FilePath -> Assertion
 unannexed = runchecks [checkregularfile, checkcontent, checkwritable]
 
-add_annex :: FilePath -> IO Bool
-add_annex f = ifM (unlockedFiles <$> getTestMode)
-	( boolSystem "git" [Param "add", File f]
-	, git_annex "add" [f]
+add_annex :: FilePath -> String -> Assertion
+add_annex f faildesc = ifM (unlockedFiles <$> getTestMode)
+	( git "add" [f] faildesc
+	, git_annex "add" [f] faildesc
 	)
 
 data TestMode = TestMode
@@ -472,8 +492,8 @@ setupTestMode :: IO ()
 setupTestMode = do
 	testmode <- getTestMode
 	when (adjustedUnlockedBranch testmode) $ do
-		boolSystem "git" [Param "commit", Param "--allow-empty", Param "-m", Param "empty"] @? "git commit failed"
-		git_annex "adjust" ["--unlock"] @? "git annex adjust failed"
+		git "commit" ["--allow-empty", "-m", "empty"] "git commit failed"
+		git_annex "adjust" ["--unlock"] "git annex adjust failed"
 
 changeToTmpDir :: FilePath -> IO ()
 changeToTmpDir t = do
