@@ -1,6 +1,6 @@
 {- git-annex Messages data types
  - 
- - Copyright 2012-2018 Joey Hess <id@joeyh.name>
+ - Copyright 2012-2020 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU AGPL version 3 or higher.
  -}
@@ -8,12 +8,20 @@
 module Types.Messages where
 
 import qualified Utility.Aeson as Aeson
+import Utility.Metered
 
 import Control.Concurrent
 import System.Console.Regions (ConsoleRegion)
+import qualified Data.ByteString as S
+import qualified Data.ByteString.Lazy as L
 
-data OutputType = NormalOutput | QuietOutput | JSONOutput JSONOptions
-	deriving (Show)
+data OutputType
+	= NormalOutput
+	| QuietOutput
+	| JSONOutput JSONOptions
+	| SerializedOutput
+		(SerializedOutput -> IO ())
+		(IO (Maybe SerializedOutputResponse))
 
 data JSONOptions = JSONOptions
 	{ jsonProgress :: Bool
@@ -53,3 +61,24 @@ newMessageState = do
 		, jsonBuffer = Nothing
 		, promptLock = promptlock
 		}
+
+-- | When communicating with a child process over a pipe while it is
+-- performing some action, this is used to pass back output that the child
+-- would normally display to the console.
+data SerializedOutput
+	= OutputMessage S.ByteString
+	| OutputError String
+	| BeginProgressMeter
+	| UpdateProgressMeterTotalSize TotalSize
+	| UpdateProgressMeter BytesProcessed
+	| EndProgressMeter
+	| BeginPrompt
+	| EndPrompt
+	| JSONObject L.ByteString
+	-- ^ This is always sent, it's up to the consumer to decide if it
+	-- wants to display JSON, or human-readable messages.
+	deriving (Show)
+
+data SerializedOutputResponse
+	= ReadyPrompt
+	deriving (Eq, Show)
