@@ -103,10 +103,9 @@ upgrade automatic destversion = do
 	-- upgrading a git repo other than the current repo.
 	upgraderemote = do
 		rp <- fromRawFilePath <$> fromRepo Git.repoPath
-		gitAnnexChildProcess
-			[ "upgrade"
-			, "--quiet"
-			, "--autoonly"
+		gitAnnexChildProcess "upgrade"
+			[ Param "--quiet"
+			, Param "--autoonly"
 			]
 			(\p -> p { cwd = Just rp })
 			(\_ _ _ pid -> waitForProcess pid >>= return . \case
