@@ -100,7 +100,7 @@ updateSymlinks = do
 					<$> calcRepo (gitAnnexLink (toRawFilePath f) k)
 				liftIO $ removeFile f
 				liftIO $ createSymbolicLink link f
-				Annex.Queue.addCommand "add" [Param "--"] [f]
+				Annex.Queue.addCommand [] "add" [Param "--"] [f]
 
 moveLocationLogs :: Annex ()
 moveLocationLogs = do
@@ -127,9 +127,9 @@ moveLocationLogs = do
 		old <- liftIO $ readLog1 f
 		new <- liftIO $ readLog1 dest
 		liftIO $ writeLog1 dest (old++new)
-		Annex.Queue.addCommand "add" [Param "--"] [dest]
-		Annex.Queue.addCommand "add" [Param "--"] [f]
-		Annex.Queue.addCommand "rm" [Param "--quiet", Param "-f", Param "--"] [f]
+		Annex.Queue.addCommand [] "add" [Param "--"] [dest]
+		Annex.Queue.addCommand [] "add" [Param "--"] [f]
+		Annex.Queue.addCommand [] "rm" [Param "--quiet", Param "-f", Param "--"] [f]
 
 oldlog2key :: FilePath -> Maybe (FilePath, Key)
 oldlog2key l
