@@ -32,6 +32,7 @@ import Git.Ref
 import Utility.InodeCache
 import Utility.DottedVersion
 import Annex.AdjustedBranch
+import qualified Utility.RawFilePath as R
 
 import qualified Data.ByteString as S
 
@@ -88,8 +89,13 @@ convertDirect = do
 	 - as does annex.thin. -}
 	setConfig (annexConfig "thin") (boolConfig True)
 	Direct.setIndirect
-	cur <- fromMaybe (error "Somehow no branch is checked out")
-		<$> inRepo Git.Branch.current
+	cur <- inRepo Git.Branch.current >>= \case
+		Just cur -> return cur
+		Nothing -> do
+			-- Avoid running pre-commit hook.
+			commitForAdjustedBranch [Param "--no-verify"]
+			fromMaybe (giveup "Nothing is committed, and a commit failed; unable to proceed.") 
+				<$> inRepo Git.Branch.current
 	upgradeDirectWorkTree
 	removeDirectCruft
 	{- Create adjusted branch where all files are unlocked.
@@ -132,13 +138,14 @@ upgradeDirectWorkTree = do
 
 	fromdirect f k = ifM (Direct.goodContent k f)
 		( do
+			let f' = toRawFilePath f
 			-- If linkToAnnex fails for some reason, the work tree
 			-- file still has the content; the annex object file
 			-- is just not populated with it. Since the work tree
 			-- file is recorded as an associated file, things will
 			-- still work that way, it's just not ideal.
-			ic <- withTSDelta (liftIO . genInodeCache (toRawFilePath f))
-			void $ Content.linkToAnnex k f ic
+			ic <- withTSDelta (liftIO . genInodeCache f')
+			void $ Content.linkToAnnex k f' ic
 		, unlessM (Content.inAnnex k) $ do
 			-- Worktree file was deleted or modified;
 			-- if there are no other copies of the content
@@ -150,7 +157,7 @@ upgradeDirectWorkTree = do
 		)
 	
 	writepointer f k = liftIO $ do
-		nukeFile f
+		removeWhenExistsWith R.removeLink (toRawFilePath f)
 		S.writeFile f (formatPointer k)
 
 {- Remove all direct mode bookkeeping files. -}
