@@ -5,6 +5,7 @@
  - Licensed under the GNU AGPL version 3 or higher.
  -}
 
+{-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE CPP #-}
 
 module Upgrade.V7 where
@@ -17,6 +18,10 @@ import qualified Database.Keys.SQL
 import qualified Git.LsFiles as LsFiles
 import qualified Git
 import Git.FilePath
+import Config
+import qualified Utility.RawFilePath as R
+
+import qualified System.FilePath.ByteString as P
 
 upgrade :: Bool -> Annex Bool
 upgrade automatic = do
@@ -32,7 +37,8 @@ upgrade automatic = do
 	-- new database is not populated. It will be automatically
 	-- populated from the git-annex branch the next time it is used.
 	removeOldDb gitAnnexContentIdentifierDbDirOld
-	liftIO . nukeFile =<< fromRepo gitAnnexContentIdentifierLockOld
+	liftIO . removeWhenExistsWith R.removeLink
+		=<< fromRepo gitAnnexContentIdentifierLockOld
 
 	-- The export databases are deleted here. The new databases
 	-- will be populated by the next thing that needs them, the same
@@ -41,31 +47,33 @@ upgrade automatic = do
 
 	populateKeysDb
 	removeOldDb gitAnnexKeysDbOld
-	liftIO . nukeFile =<< fromRepo gitAnnexKeysDbIndexCacheOld
-	liftIO . nukeFile =<< fromRepo gitAnnexKeysDbLockOld
+	liftIO . removeWhenExistsWith R.removeLink
+		=<< fromRepo gitAnnexKeysDbIndexCacheOld
+	liftIO . removeWhenExistsWith R.removeLink
+		=<< fromRepo gitAnnexKeysDbLockOld
 	
 	updateSmudgeFilter
 
 	return True
 
-gitAnnexKeysDbOld :: Git.Repo -> FilePath
-gitAnnexKeysDbOld r = fromRawFilePath (gitAnnexDir r) </> "keys"
+gitAnnexKeysDbOld :: Git.Repo -> RawFilePath
+gitAnnexKeysDbOld r = gitAnnexDir r P.</> "keys"
 
-gitAnnexKeysDbLockOld :: Git.Repo -> FilePath
-gitAnnexKeysDbLockOld r = gitAnnexKeysDbOld r ++ ".lck"
+gitAnnexKeysDbLockOld :: Git.Repo -> RawFilePath
+gitAnnexKeysDbLockOld r = gitAnnexKeysDbOld r <> ".lck"
 
-gitAnnexKeysDbIndexCacheOld :: Git.Repo -> FilePath
-gitAnnexKeysDbIndexCacheOld r = gitAnnexKeysDbOld r ++ ".cache"
+gitAnnexKeysDbIndexCacheOld :: Git.Repo -> RawFilePath
+gitAnnexKeysDbIndexCacheOld r = gitAnnexKeysDbOld r <> ".cache"
 
-gitAnnexContentIdentifierDbDirOld :: Git.Repo -> FilePath
-gitAnnexContentIdentifierDbDirOld r = fromRawFilePath (gitAnnexDir r) </> "cids"
+gitAnnexContentIdentifierDbDirOld :: Git.Repo -> RawFilePath
+gitAnnexContentIdentifierDbDirOld r = gitAnnexDir r P.</> "cids"
 
-gitAnnexContentIdentifierLockOld :: Git.Repo -> FilePath
-gitAnnexContentIdentifierLockOld r = gitAnnexContentIdentifierDbDirOld r ++ ".lck"
+gitAnnexContentIdentifierLockOld :: Git.Repo -> RawFilePath
+gitAnnexContentIdentifierLockOld r = gitAnnexContentIdentifierDbDirOld r <> ".lck"
 
-removeOldDb :: (Git.Repo -> FilePath) -> Annex ()
+removeOldDb :: (Git.Repo -> RawFilePath) -> Annex ()
 removeOldDb getdb = do
-	db <- fromRepo getdb
+	db <- fromRawFilePath <$> fromRepo getdb
 	whenM (liftIO $ doesDirectoryExist db) $ do
 		v <- liftIO $ tryNonAsync $
 #if MIN_VERSION_directory(1,2,7)
@@ -96,7 +104,7 @@ removeOldDb getdb = do
 -- annex object. That work is only done once, and then the object will
 -- finally get its inode cached.
 populateKeysDb :: Annex ()
-populateKeysDb = do
+populateKeysDb = unlessM isBareRepo $ do
 	top <- fromRepo Git.repoPath
 	(l, cleanup) <- inRepo $ LsFiles.inodeCaches [top]
 	forM_ l $ \case
@@ -120,7 +128,7 @@ populateKeysDb = do
 -- checked into the repository.
 updateSmudgeFilter :: Annex ()
 updateSmudgeFilter = do
-	lf <- Annex.fromRepo Git.attributesLocal
+	lf <- fromRawFilePath <$> Annex.fromRepo Git.attributesLocal
 	ls <- liftIO $ lines <$> catchDefaultIO "" (readFileStrict lf)
 	let ls' = removedotfilter ls
 	when (ls /= ls') $
