@@ -9,6 +9,9 @@
 
 {-# LANGUAGE ScopedTypeVariables, DeriveDataTypeable, LambdaCase, PatternGuards #-}
 
+-- This is a vendored copy of Network.HTTP.Client.Restricted from the
+-- http-client-restricted package, and will be removed once that package
+-- is available in all build environments.
 module Utility.HttpManagerRestricted (
 	Restriction,
 	checkAddressRestriction,
@@ -21,8 +24,7 @@ module Utility.HttpManagerRestricted (
 ) where
 
 import Network.HTTP.Client
-import Network.HTTP.Client.Internal
-	(ManagerSettings(..), Connection, runProxyOverride, makeConnection)
+import Network.HTTP.Client.Internal (ManagerSettings(..), Connection, runProxyOverride)
 import Network.HTTP.Client.TLS (mkManagerSettingsContext)
 import Network.Socket
 import Network.BSD (getProtocolNumber)
