@@ -41,6 +41,7 @@ module Utility.Url (
 	GetBasicAuth,
 	noBasicAuth,
 	applyBasicAuth',
+	extractFromResourceT,
 ) where
 
 import Common
@@ -51,6 +52,7 @@ import Network.HTTP.Client.Restricted
 import Utility.HttpManagerRestricted
 #endif
 import Utility.IPAddress
+import qualified Utility.RawFilePath as R
 
 import Network.URI
 import Network.HTTP.Types
@@ -60,8 +62,10 @@ import qualified Data.ByteString as B
 import qualified Data.ByteString.UTF8 as B8
 import qualified Data.ByteString.Lazy as L
 import qualified Data.Set as S
-import Control.Exception (throwIO)
+import Control.Exception (throwIO, evaluate)
 import Control.Monad.Trans.Resource
+import Control.Monad.IO.Class (MonadIO)
+import Control.DeepSeq
 import Network.HTTP.Conduit
 import Network.HTTP.Client
 import Network.HTTP.Simple (getResponseHeader)
@@ -269,12 +273,10 @@ getUrlInfo url uo = case parseURIRelaxed url of
 		debugM "url" (show req')
 		join $ runResourceT $ do
 			resp <- http req' (httpManager uo)
-			-- forces processing the response while
-			-- within the runResourceT
-			liftIO $ if responseStatus resp == ok200
+			if responseStatus resp == ok200
 				then do
-					let !len = extractlen resp
-					let !fn = extractfilename resp
+					len <- extractFromResourceT (extractlen resp)
+					fn <- extractFromResourceT (extractfilename resp)
 					return $ found len fn
 				else if responseStatus resp == unauthorized401
 					then return $ getBasicAuth uo' (show (getUri req)) >>= \case
@@ -308,8 +310,8 @@ getUrlInfo url uo = case parseURIRelaxed url of
 		=<< curlRestrictedParams r u defport (basecurlparams url')
 
 	existsfile u = do
-		let f = unEscapeString (uriPath u)
-		s <- catchMaybeIO $ getFileStatus f
+		let f = toRawFilePath (unEscapeString (uriPath u))
+		s <- catchMaybeIO $ R.getFileStatus f
 		case s of
 			Just stat -> do
 				sz <- getFileSize' f stat
@@ -450,11 +452,16 @@ download' nocurlerror meterupdate url file uo =
 {- Download a perhaps large file using conduit, with auto-resume
  - of incomplete downloads.
  -
- - Does not catch exceptions.
+ - A Request can be configured to throw exceptions for non-2xx http
+ - status codes, or not. That configuration is overridden by this,
+ - and if it is unable to download, it throws an exception containing
+ - a user-visible explanation of the problem. (However, exceptions
+ - thrown for reasons other than http status codes will still be thrown
+ - as usual.)
  -}
 downloadConduit :: MeterUpdate -> Request -> FilePath -> UrlOptions -> IO ()
 downloadConduit meterupdate req file uo =
-	catchMaybeIO (getFileSize file) >>= \case
+	catchMaybeIO (getFileSize (toRawFilePath file)) >>= \case
 		Just sz | sz > 0 -> resumedownload sz
 		_ -> join $ runResourceT $ do
 			liftIO $ debugM "url" (show req')
@@ -463,11 +470,13 @@ downloadConduit meterupdate req file uo =
 				then do
 					store zeroBytesProcessed WriteMode resp
 					return (return ())
-				else if responseStatus resp == unauthorized401
-					then return $ getBasicAuth uo (show (getUri req')) >>= \case
-						Nothing -> respfailure resp
-						Just ba -> retryauthed ba
-					else return $ respfailure resp
+				else do
+					rf <- extractFromResourceT (respfailure resp)
+					if responseStatus resp == unauthorized401
+						then return $ getBasicAuth uo (show (getUri req')) >>= \case
+							Nothing -> giveup rf
+							Just ba -> retryauthed ba
+						else return $ giveup rf
   where
 	req' = applyRequest uo $ req
 		-- Override http-client's default decompression of gzip
@@ -476,36 +485,40 @@ downloadConduit meterupdate req file uo =
 			filter ((/= hAcceptEncoding) . fst)
 				(requestHeaders req)
 		, decompress = const False
+		-- Avoid throwing exceptions non-2xx http status codes,
+		-- since we rely on parsing the Response to handle
+		-- several such codes.
+		, checkResponse = \_ _ -> return ()
 		}
 
 	-- Resume download from where a previous download was interrupted, 
 	-- when supported by the http server. The server may also opt to
 	-- send the whole file rather than resuming.
-	resumedownload sz = catchJust
-		(matchStatusCodeHeadersException (alreadydownloaded sz))
-		dl
-		(const noop)
-	  where
-		dl = join $ runResourceT $ do
-			let req'' = req' { requestHeaders = resumeFromHeader sz : requestHeaders req }
-			liftIO $ debugM "url" (show req'')
-			resp <- http req'' (httpManager uo)
-			if responseStatus resp == partialContent206
+	resumedownload sz = join $ runResourceT $ do
+		let req'' = req' { requestHeaders = resumeFromHeader sz : requestHeaders req' }
+		liftIO $ debugM "url" (show req'')
+		resp <- http req'' (httpManager uo)
+		if responseStatus resp == partialContent206
+			then do
+				store (toBytesProcessed sz) AppendMode resp
+				return (return ())
+			else if responseStatus resp == ok200
 				then do
-					store (toBytesProcessed sz) AppendMode resp
+					store zeroBytesProcessed WriteMode resp
 					return (return ())
-				else if responseStatus resp == ok200
-					then do
-						store zeroBytesProcessed WriteMode resp
-						return (return ())
-					else if responseStatus resp == unauthorized401
-						then return $ getBasicAuth uo (show (getUri req'')) >>= \case
-							Nothing -> respfailure resp
-							Just ba -> retryauthed ba
-						else return $ respfailure resp
+				else if alreadydownloaded sz resp
+					then return (return ())
+					else do
+						rf <- extractFromResourceT (respfailure resp)
+						if responseStatus resp == unauthorized401
+							then return $ getBasicAuth uo (show (getUri req'')) >>= \case
+								Nothing -> giveup rf
+								Just ba -> retryauthed ba
+							else return $ giveup rf
 	
-	alreadydownloaded sz s h = s == requestedRangeNotSatisfiable416 
-		&& case lookup hContentRange h of
+	alreadydownloaded sz resp
+		| responseStatus resp /= requestedRangeNotSatisfiable416 = False
+		| otherwise = case lookup hContentRange (responseHeaders resp) of
 			-- This could be improved by fixing
 			-- https://github.com/aristidb/http-types/issues/87
 			Just crh -> crh == B8.fromString ("bytes */" ++ show sz)
@@ -521,7 +534,7 @@ downloadConduit meterupdate req file uo =
 	store initialp mode resp =
 		sinkResponseFile meterupdate initialp file mode resp
 	
-	respfailure = giveup . B8.toString . statusMessage . responseStatus
+	respfailure = B8.toString . statusMessage . responseStatus
 	
 	retryauthed (ba, signalsuccess) = do
 		r <- tryNonAsync $ downloadConduit
@@ -710,3 +723,11 @@ applyBasicAuth' :: BasicAuth -> Request -> Request
 applyBasicAuth' ba = applyBasicAuth
 	(encodeBS (basicAuthUser ba))
 	(encodeBS (basicAuthPassword ba))
+
+{- Make sure whatever is returned is fully evaluated. Avoids any possible
+ - issues with laziness deferring processing until a time when the resource
+ - has been freed. -}
+extractFromResourceT :: (MonadIO m, NFData a) => a -> ResourceT m a
+extractFromResourceT v = do
+	liftIO $ evaluate (rnf v)
+	return v
