@@ -36,9 +36,6 @@ import Blaze.ByteString.Builder (Builder)
 import Control.Arrow ((***))
 import Control.Concurrent
 
-localhost :: HostName
-localhost = "localhost"
-
 {- Builds a command to use to start or open a web browser showing an url. -}
 browserProc :: String -> CreateProcess
 #ifdef darwin_HOST_OS
@@ -85,15 +82,16 @@ webAppSettings = setTimeout halfhour defaultSettings
  -}
 getSocket :: Maybe HostName -> IO Socket
 getSocket h = do
-#if defined(__ANDROID__) || defined (mingw32_HOST_OS)
-	-- getAddrInfo currently segfaults on Android.
+#if defined (mingw32_HOST_OS)
 	-- The HostName is ignored by this code.
+	-- getAddrInfo didn't used to work on windows; current status
+	-- unknown.
 	when (isJust h) $
 		error "getSocket with HostName not supported on this OS"
-	addr <- inet_addr "127.0.0.1"
+	let addr = tupleToHostAddress (127,0,0,1)
 	sock <- socket AF_INET Stream defaultProtocol
 	preparesocket sock
-	bind sock (SockAddrInet aNY_PORT addr)
+	bind sock (SockAddrInet defaultPort addr)
 	use sock
   where
 #else
@@ -104,6 +102,7 @@ getSocket h = do
 		_ -> error "unable to bind to a local socket"
   where
 	hostname = fromMaybe localhost h
+	localhost = "localhost"
 	hints = defaultHints { addrSocketType = Stream }
 	{- Repeated attempts because bind sometimes fails for an
 	 - unknown reason on OSX. -} 
@@ -188,7 +187,8 @@ insertAuthToken extractAuthToken predicate webapp root pathbits params =
 {- Creates a html shim file that's used to redirect into the webapp,
  - to avoid exposing the secret token when launching the web browser. -}
 writeHtmlShim :: String -> String -> FilePath -> IO ()
-writeHtmlShim title url file = viaTmp writeFileProtected file $ genHtmlShim title url
+writeHtmlShim title url file = 
+	viaTmp (writeFileProtected . toRawFilePath) file $ genHtmlShim title url
 
 genHtmlShim :: String -> String -> String
 genHtmlShim title url = unlines
